import React, { createElement, Component } from 'react';
import PropTypes from 'prop-types';

var classCallCheck = function (instance, Constructor) {
  if (!(instance instanceof Constructor)) {
    throw new TypeError("Cannot call a class as a function");
  }
};

var createClass = function () {
  function defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];
      descriptor.enumerable = descriptor.enumerable || false;
      descriptor.configurable = true;
      if ("value" in descriptor) descriptor.writable = true;
      Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  return function (Constructor, protoProps, staticProps) {
    if (protoProps) defineProperties(Constructor.prototype, protoProps);
    if (staticProps) defineProperties(Constructor, staticProps);
    return Constructor;
  };
}();

var _extends = Object.assign || function (target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i];

    for (var key in source) {
      if (Object.prototype.hasOwnProperty.call(source, key)) {
        target[key] = source[key];
      }
    }
  }

  return target;
};

var inherits = function (subClass, superClass) {
  if (typeof superClass !== "function" && superClass !== null) {
    throw new TypeError("Super expression must either be null or a function, not " + typeof superClass);
  }

  subClass.prototype = Object.create(superClass && superClass.prototype, {
    constructor: {
      value: subClass,
      enumerable: false,
      writable: true,
      configurable: true
    }
  });
  if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass;
};

var possibleConstructorReturn = function (self, call) {
  if (!self) {
    throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
  }

  return call && (typeof call === "object" || typeof call === "function") ? call : self;
};

var styles = {
  base: {
    position: 'absolute',
    userSelect: 'none',
    MsUserSelect: 'none'
  },
  top: {
    width: '100%',
    height: '10px',
    top: '-5px',
    left: '0px',
    cursor: 'row-resize'
  },
  right: {
    width: '10px',
    height: '100%',
    top: '0px',
    right: '-5px',
    cursor: 'col-resize'
  },
  bottom: {
    width: '100%',
    height: '10px',
    bottom: '-5px',
    left: '0px',
    cursor: 'row-resize'
  },
  left: {
    width: '10px',
    height: '100%',
    top: '0px',
    left: '-5px',
    cursor: 'col-resize'
  },
  topRight: {
    width: '20px',
    height: '20px',
    position: 'absolute',
    right: '-10px',
    top: '-10px',
    cursor: 'ne-resize'
  },
  bottomRight: {
    width: '20px',
    height: '20px',
    position: 'absolute',
    right: '-10px',
    bottom: '-10px',
    cursor: 'se-resize'
  },
  bottomLeft: {
    width: '20px',
    height: '20px',
    position: 'absolute',
    left: '-10px',
    bottom: '-10px',
    cursor: 'sw-resize'
  },
  topLeft: {
    width: '20px',
    height: '20px',
    position: 'absolute',
    left: '-10px',
    top: '-10px',
    cursor: 'nw-resize'
  }
};

var Resizer = (function (props) {
  return createElement(
    'div',
    {
      className: props.className,
      style: _extends({}, styles.base, styles[props.direction], props.replaceStyles || {}),
      onMouseDown: function onMouseDown(e) {
        props.onResizeStart(e, props.direction);
      },
      onTouchStart: function onTouchStart(e) {
        props.onResizeStart(e, props.direction);
      }
    },
    props.children
  );
});

var userSelectNone = {
  userSelect: 'none',
  MozUserSelect: 'none',
  WebkitUserSelect: 'none',
  MsUserSelect: 'none'
};

var userSelectAuto = {
  userSelect: 'auto',
  MozUserSelect: 'auto',
  WebkitUserSelect: 'auto',
  MsUserSelect: 'auto'
};

var clamp = function clamp(n, min, max) {
  return Math.max(Math.min(n, max), min);
};
var snap = function snap(n, size) {
  return Math.round(n / size) * size;
};

var findClosestSnap = function findClosestSnap(n, snapArray) {
  return snapArray.reduce(function (prev, curr) {
    return Math.abs(curr - n) < Math.abs(prev - n) ? curr : prev;
  });
};

var endsWith = function endsWith(str, searchStr) {
  return str.substr(str.length - searchStr.length, searchStr.length) === searchStr;
};

var getStringSize = function getStringSize(n) {
  if (n.toString() === 'auto') return n.toString();
  if (endsWith(n.toString(), 'px')) return n.toString();
  if (endsWith(n.toString(), '%')) return n.toString();
  if (endsWith(n.toString(), 'vh')) return n.toString();
  if (endsWith(n.toString(), 'vw')) return n.toString();
  if (endsWith(n.toString(), 'vmax')) return n.toString();
  if (endsWith(n.toString(), 'vmin')) return n.toString();
  return n + 'px';
};

var definedProps = ['style', 'className', 'grid', 'snap', 'bounds', 'size', 'defaultSize', 'minWidth', 'minHeight', 'maxWidth', 'maxHeight', 'lockAspectRatio', 'lockAspectRatioExtraWidth', 'lockAspectRatioExtraHeight', 'enable', 'handleStyles', 'handleClasses', 'handleWrapperStyle', 'handleWrapperClass', 'children', 'onResizeStart', 'onResize', 'onResizeStop', 'handleComponent'];

var baseClassName = '__resizable_base__';

var Resizable = function (_React$Component) {
  inherits(Resizable, _React$Component);

  function Resizable(props) {
    classCallCheck(this, Resizable);

    var _this = possibleConstructorReturn(this, (Resizable.__proto__ || Object.getPrototypeOf(Resizable)).call(this, props));

    _this.state = {
      isResizing: false,
      resizeCursor: 'auto',
      width: typeof (_this.propsSize && _this.propsSize.width) === 'undefined' ? 'auto' : _this.propsSize && _this.propsSize.width,
      height: typeof (_this.propsSize && _this.propsSize.height) === 'undefined' ? 'auto' : _this.propsSize && _this.propsSize.height,
      direction: 'right',
      original: {
        x: 0,
        y: 0,
        width: 0,
        height: 0
      }
    };

    _this.updateExtendsProps(props);
    _this.onResizeStart = _this.onResizeStart.bind(_this);
    _this.onMouseMove = _this.onMouseMove.bind(_this);
    _this.onMouseUp = _this.onMouseUp.bind(_this);

    if (typeof window !== 'undefined') {
      window.addEventListener('mouseup', _this.onMouseUp);
      window.addEventListener('mousemove', _this.onMouseMove);
      window.addEventListener('mouseleave', _this.onMouseUp);
      window.addEventListener('touchmove', _this.onMouseMove);
      window.addEventListener('touchend', _this.onMouseUp);
    }
    return _this;
  }

  createClass(Resizable, [{
    key: 'updateExtendsProps',
    value: function updateExtendsProps(props) {
      this.extendsProps = Object.keys(props).reduce(function (acc, key) {
        if (definedProps.indexOf(key) !== -1) return acc;
        acc[key] = props[key];
        return acc;
      }, {});
    }
  }, {
    key: 'getParentSize',
    value: function getParentSize() {
      var base = this.base;

      if (!base) return { width: window.innerWidth, height: window.innerHeight };
      // INFO: To calculate parent width with flex layout
      var wrapChanged = false;
      var wrap = this.parentNode.style.flexWrap;
      var minWidth = base.style.minWidth;
      if (wrap !== 'wrap') {
        wrapChanged = true;
        this.parentNode.style.flexWrap = 'wrap';
        // HACK: Use relative to get parent padding size
      }
      base.style.position = 'relative';
      base.style.minWidth = '100%';
      var size = {
        width: base.offsetWidth,
        height: base.offsetHeight
      };
      base.style.position = 'absolute';
      if (wrapChanged) this.parentNode.style.flexWrap = wrap;
      base.style.minWidth = minWidth;
      return size;
    }
  }, {
    key: 'componentDidMount',
    value: function componentDidMount() {
      var size = this.size;

      this.setState({
        width: this.state.width || size.width,
        height: this.state.height || size.height
      });
      var parent = this.parentNode;
      if (!(parent instanceof HTMLElement)) return;
      if (this.base) return;
      var element = document.createElement('div');
      element.style.width = '100%';
      element.style.height = '100%';
      element.style.position = 'absolute';
      element.style.transform = 'scale(0, 0)';
      element.style.left = '0';
      element.style.flex = '0';
      if (element.classList) {
        element.classList.add(baseClassName);
      } else {
        element.className += baseClassName;
      }
      parent.appendChild(element);
    }
  }, {
    key: 'componentWillReceiveProps',
    value: function componentWillReceiveProps(next) {
      this.updateExtendsProps(next);
    }
  }, {
    key: 'componentWillUnmount',
    value: function componentWillUnmount() {
      if (typeof window !== 'undefined') {
        window.removeEventListener('mouseup', this.onMouseUp);
        window.removeEventListener('mousemove', this.onMouseMove);
        window.removeEventListener('mouseleave', this.onMouseUp);
        window.removeEventListener('touchmove', this.onMouseMove);
        window.removeEventListener('touchend', this.onMouseUp);
        var parent = this.parentNode;
        var base = this.base;

        if (!base || !parent) return;
        if (!(parent instanceof HTMLElement) || !(base instanceof Node)) return;
        parent.removeChild(base);
      }
    }
  }, {
    key: 'calculateNewSize',
    value: function calculateNewSize(newSize, kind) {
      var propsSize = this.propsSize && this.propsSize[kind];
      return this.state[kind] === 'auto' && this.state.original[kind] === newSize && (typeof propsSize === 'undefined' || propsSize === 'auto') ? 'auto' : newSize;
    }
  }, {
    key: 'onResizeStart',
    value: function onResizeStart(event, direction) {
      var clientX = 0;
      var clientY = 0;
      if (event.nativeEvent instanceof MouseEvent) {
        clientX = event.nativeEvent.clientX;
        clientY = event.nativeEvent.clientY;

        // When user click with right button the resize is stuck in resizing mode
        // until users clicks again, dont continue if right click is used.
        // HACK: MouseEvent does not have `which` from flow-bin v0.68.
        if (event.nativeEvent.which === 3) {
          return;
        }
      } else if (event.nativeEvent instanceof TouchEvent) {
        clientX = event.nativeEvent.touches[0].clientX;
        clientY = event.nativeEvent.touches[0].clientY;
      }
      if (this.props.onResizeStart) {
        this.props.onResizeStart(event, direction, this.resizable);
      }

      // Fix #168
      if (this.props.size) {
        if (typeof this.props.size.height !== 'undefined' && this.props.size.height !== this.state.height) {
          this.setState({ height: this.props.size.height });
        }
        if (typeof this.props.size.width !== 'undefined' && this.props.size.width !== this.state.width) {
          this.setState({ width: this.props.size.width });
        }
      }

      this.setState({
        original: {
          x: clientX,
          y: clientY,
          width: this.size.width,
          height: this.size.height
        },
        isResizing: true,
        resizeCursor: window.getComputedStyle(event.target).cursor,
        direction: direction
      });
    }
  }, {
    key: 'onMouseMove',
    value: function onMouseMove(event) {
      if (!this.state.isResizing) return;
      var clientX = event instanceof MouseEvent ? event.clientX : event.touches[0].clientX;
      var clientY = event instanceof MouseEvent ? event.clientY : event.touches[0].clientY;
      var _state = this.state,
          direction = _state.direction,
          original = _state.original,
          width = _state.width,
          height = _state.height;
      var _props = this.props,
          lockAspectRatio = _props.lockAspectRatio,
          lockAspectRatioExtraHeight = _props.lockAspectRatioExtraHeight,
          lockAspectRatioExtraWidth = _props.lockAspectRatioExtraWidth;
      var _props2 = this.props,
          maxWidth = _props2.maxWidth,
          maxHeight = _props2.maxHeight,
          minWidth = _props2.minWidth,
          minHeight = _props2.minHeight;

      // TODO: refactor

      var parentSize = this.getParentSize();
      if (maxWidth && typeof maxWidth === 'string' && endsWith(maxWidth, '%')) {
        var _ratio = Number(maxWidth.replace('%', '')) / 100;
        maxWidth = parentSize.width * _ratio;
      }
      if (maxHeight && typeof maxHeight === 'string' && endsWith(maxHeight, '%')) {
        var _ratio2 = Number(maxHeight.replace('%', '')) / 100;
        maxHeight = parentSize.height * _ratio2;
      }
      if (minWidth && typeof minWidth === 'string' && endsWith(minWidth, '%')) {
        var _ratio3 = Number(minWidth.replace('%', '')) / 100;
        minWidth = parentSize.width * _ratio3;
      }
      if (minHeight && typeof minHeight === 'string' && endsWith(minHeight, '%')) {
        var _ratio4 = Number(minHeight.replace('%', '')) / 100;
        minHeight = parentSize.height * _ratio4;
      }
      maxWidth = typeof maxWidth === 'undefined' ? undefined : Number(maxWidth);
      maxHeight = typeof maxHeight === 'undefined' ? undefined : Number(maxHeight);
      minWidth = typeof minWidth === 'undefined' ? undefined : Number(minWidth);
      minHeight = typeof minHeight === 'undefined' ? undefined : Number(minHeight);

      var ratio = typeof lockAspectRatio === 'number' ? lockAspectRatio : original.width / original.height;
      var newWidth = original.width;
      var newHeight = original.height;
      if (/right/i.test(direction)) {
        newWidth = original.width + (clientX - original.x);
        if (lockAspectRatio) newHeight = (newWidth - lockAspectRatioExtraWidth) / ratio + lockAspectRatioExtraHeight;
      }
      if (/left/i.test(direction)) {
        newWidth = original.width - (clientX - original.x);
        if (lockAspectRatio) newHeight = (newWidth - lockAspectRatioExtraWidth) / ratio + lockAspectRatioExtraHeight;
      }
      if (/bottom/i.test(direction)) {
        newHeight = original.height + (clientY - original.y);
        if (lockAspectRatio) newWidth = (newHeight - lockAspectRatioExtraHeight) * ratio + lockAspectRatioExtraWidth;
      }
      if (/top/i.test(direction)) {
        newHeight = original.height - (clientY - original.y);
        if (lockAspectRatio) newWidth = (newHeight - lockAspectRatioExtraHeight) * ratio + lockAspectRatioExtraWidth;
      }

      if (this.props.bounds === 'parent') {
        var parent = this.parentNode;
        if (parent instanceof HTMLElement) {
          var parentRect = parent.getBoundingClientRect();
          var parentLeft = parentRect.left;
          var parentTop = parentRect.top;

          var _resizable$getBoundin = this.resizable.getBoundingClientRect(),
              _left = _resizable$getBoundin.left,
              _top = _resizable$getBoundin.top;

          var boundWidth = parent.offsetWidth + (parentLeft - _left);
          var boundHeight = parent.offsetHeight + (parentTop - _top);
          maxWidth = maxWidth && maxWidth < boundWidth ? maxWidth : boundWidth;
          maxHeight = maxHeight && maxHeight < boundHeight ? maxHeight : boundHeight;
        }
      } else if (this.props.bounds === 'window') {
        if (typeof window !== 'undefined') {
          var _resizable$getBoundin2 = this.resizable.getBoundingClientRect(),
              _left2 = _resizable$getBoundin2.left,
              _top2 = _resizable$getBoundin2.top;

          var _boundWidth = window.innerWidth - _left2;
          var _boundHeight = window.innerHeight - _top2;
          maxWidth = maxWidth && maxWidth < _boundWidth ? maxWidth : _boundWidth;
          maxHeight = maxHeight && maxHeight < _boundHeight ? maxHeight : _boundHeight;
        }
      } else if (this.props.bounds instanceof HTMLElement) {
        var targetRect = this.props.bounds.getBoundingClientRect();
        var targetLeft = targetRect.left;
        var targetTop = targetRect.top;

        var _resizable$getBoundin3 = this.resizable.getBoundingClientRect(),
            _left3 = _resizable$getBoundin3.left,
            _top3 = _resizable$getBoundin3.top;

        if (!(this.props.bounds instanceof HTMLElement)) return;
        var _boundWidth2 = this.props.bounds.offsetWidth + (targetLeft - _left3);
        var _boundHeight2 = this.props.bounds.offsetHeight + (targetTop - _top3);
        maxWidth = maxWidth && maxWidth < _boundWidth2 ? maxWidth : _boundWidth2;
        maxHeight = maxHeight && maxHeight < _boundHeight2 ? maxHeight : _boundHeight2;
      }

      var computedMinWidth = typeof minWidth === 'undefined' ? 10 : minWidth;
      var computedMaxWidth = typeof maxWidth === 'undefined' || maxWidth < 0 ? newWidth : maxWidth;
      var computedMinHeight = typeof minHeight === 'undefined' ? 10 : minHeight;
      var computedMaxHeight = typeof maxHeight === 'undefined' || maxHeight < 0 ? newHeight : maxHeight;

      if (lockAspectRatio) {
        var extraMinWidth = (computedMinHeight - lockAspectRatioExtraHeight) * ratio + lockAspectRatioExtraWidth;
        var extraMaxWidth = (computedMaxHeight - lockAspectRatioExtraHeight) * ratio + lockAspectRatioExtraWidth;
        var extraMinHeight = (computedMinWidth - lockAspectRatioExtraWidth) / ratio + lockAspectRatioExtraHeight;
        var extraMaxHeight = (computedMaxWidth - lockAspectRatioExtraWidth) / ratio + lockAspectRatioExtraHeight;
        var lockedMinWidth = Math.max(computedMinWidth, extraMinWidth);
        var lockedMaxWidth = Math.min(computedMaxWidth, extraMaxWidth);
        var lockedMinHeight = Math.max(computedMinHeight, extraMinHeight);
        var lockedMaxHeight = Math.min(computedMaxHeight, extraMaxHeight);
        newWidth = clamp(newWidth, lockedMinWidth, lockedMaxWidth);
        newHeight = clamp(newHeight, lockedMinHeight, lockedMaxHeight);
      } else {
        newWidth = clamp(newWidth, computedMinWidth, computedMaxWidth);
        newHeight = clamp(newHeight, computedMinHeight, computedMaxHeight);
      }
      if (this.props.grid) {
        newWidth = snap(newWidth, this.props.grid[0]);
      }
      if (this.props.grid) {
        newHeight = snap(newHeight, this.props.grid[1]);
      }

      if (this.props.snap && this.props.snap.x) {
        newWidth = findClosestSnap(newWidth, this.props.snap.x);
      }
      if (this.props.snap && this.props.snap.y) {
        newHeight = findClosestSnap(newHeight, this.props.snap.y);
      }

      var delta = {
        width: newWidth - original.width,
        height: newHeight - original.height
      };

      if (width && typeof width === 'string' && endsWith(width, '%')) {
        var percent = newWidth / parentSize.width * 100;
        newWidth = percent + '%';
      }

      if (height && typeof height === 'string' && endsWith(height, '%')) {
        var _percent = newHeight / parentSize.height * 100;
        newHeight = _percent + '%';
      }

      this.setState({
        width: this.calculateNewSize(newWidth, 'width'),
        height: this.calculateNewSize(newHeight, 'height')
      });

      if (this.props.onResize) {
        this.props.onResize(event, direction, this.resizable, delta);
      }
    }
  }, {
    key: 'onMouseUp',
    value: function onMouseUp(event) {
      var _state2 = this.state,
          isResizing = _state2.isResizing,
          direction = _state2.direction,
          original = _state2.original;

      if (!isResizing) return;
      var delta = {
        width: this.size.width - original.width,
        height: this.size.height - original.height
      };
      if (this.props.onResizeStop) {
        this.props.onResizeStop(event, direction, this.resizable, delta);
      }
      if (this.props.size) {
        this.setState(this.props.size);
      }
      this.setState({ isResizing: false, resizeCursor: 'auto' });
    }
  }, {
    key: 'updateSize',
    value: function updateSize(size) {
      this.setState({ width: size.width, height: size.height });
    }
  }, {
    key: 'renderResizer',
    value: function renderResizer() {
      var _this2 = this;

      var _props3 = this.props,
          enable = _props3.enable,
          handleStyles = _props3.handleStyles,
          handleClasses = _props3.handleClasses,
          handleWrapperStyle = _props3.handleWrapperStyle,
          handleWrapperClass = _props3.handleWrapperClass,
          handleComponent = _props3.handleComponent;

      if (!enable) return null;
      var resizers = Object.keys(enable).map(function (dir) {
        if (enable[dir] !== false) {
          return createElement(
            Resizer,
            {
              key: dir,
              direction: dir,
              onResizeStart: _this2.onResizeStart,
              replaceStyles: handleStyles && handleStyles[dir],
              className: handleClasses && handleClasses[dir]
            },
            handleComponent && handleComponent[dir] ? createElement(handleComponent[dir]) : null
          );
        }
        return null;
      });
      // #93 Wrap the resize box in span (will not break 100% width/height)
      return createElement(
        'span',
        { className: handleWrapperClass, style: handleWrapperStyle },
        resizers
      );
    }
  }, {
    key: 'render',
    value: function render() {
      var _this3 = this;

      var userSelect = this.state.isResizing ? userSelectNone : userSelectAuto;
      return createElement(
        'div',
        _extends({
          ref: function ref(c) {
            if (c) {
              _this3.resizable = c;
            }
          },
          style: _extends({
            position: 'relative'
          }, userSelect, this.props.style, this.sizeStyle, {
            maxWidth: this.props.maxWidth,
            maxHeight: this.props.maxHeight,
            minWidth: this.props.minWidth,
            minHeight: this.props.minHeight,
            boxSizing: 'border-box'
          }),
          className: this.props.className
        }, this.extendsProps),
        this.state.isResizing && createElement('div', {
          style: {
            height: '100%',
            width: '100%',
            backgroundColor: 'rgba(0,0,0,0)',
            cursor: '' + (this.state.resizeCursor || 'auto'),
            opacity: '0',
            position: 'fixed',
            zIndex: '9999',
            top: '0',
            left: '0',
            bottom: '0',
            right: '0'
          }
        }),
        this.props.children,
        this.renderResizer()
      );
    }
  }, {
    key: 'parentNode',
    get: function get$$1() {
      return this.resizable.parentNode;
    }
  }, {
    key: 'propsSize',
    get: function get$$1() {
      return this.props.size || this.props.defaultSize;
    }
  }, {
    key: 'base',
    get: function get$$1() {
      var parent = this.parentNode;
      if (!parent) return undefined;
      var children = [].slice.call(parent.children);
      for (var i = 0; i < children.length; i += 1) {
        var n = children[i];
        if (n instanceof HTMLElement) {
          if (n.classList.contains(baseClassName)) {
            return n;
          }
        }
      }
      return undefined;
    }
  }, {
    key: 'size',
    get: function get$$1() {
      var width = 0;
      var height = 0;
      if (typeof window !== 'undefined') {
        var orgWidth = this.resizable.offsetWidth;
        var orgHeight = this.resizable.offsetHeight;
        // HACK: Set position `relative` to get parent size.
        //       This is because when re-resizable set `absolute`, I can not get base width correctly.
        var orgPosition = this.resizable.style.position;
        if (orgPosition !== 'relative') {
          this.resizable.style.position = 'relative';
        }
        // INFO: Use original width or height if set auto.
        width = this.resizable.style.width !== 'auto' ? this.resizable.offsetWidth : orgWidth;
        height = this.resizable.style.height !== 'auto' ? this.resizable.offsetHeight : orgHeight;
        // Restore original position
        this.resizable.style.position = orgPosition;
      }
      return { width: width, height: height };
    }
  }, {
    key: 'sizeStyle',
    get: function get$$1() {
      var _this4 = this;

      var size = this.props.size;

      var getSize = function getSize(key) {
        if (typeof _this4.state[key] === 'undefined' || _this4.state[key] === 'auto') return 'auto';
        if (_this4.propsSize && _this4.propsSize[key] && endsWith(_this4.propsSize[key].toString(), '%')) {
          if (endsWith(_this4.state[key].toString(), '%')) return _this4.state[key].toString();
          var parentSize = _this4.getParentSize();
          var value = Number(_this4.state[key].toString().replace('px', ''));
          var percent = value / parentSize[key] * 100;
          return percent + '%';
        }
        return getStringSize(_this4.state[key]);
      };
      var width = size && typeof size.width !== 'undefined' && !this.state.isResizing ? getStringSize(size.width) : getSize('width');
      var height = size && typeof size.height !== 'undefined' && !this.state.isResizing ? getStringSize(size.height) : getSize('height');
      return { width: width, height: height };
    }
  }]);
  return Resizable;
}(Component);

Resizable.defaultProps = {
  onResizeStart: function onResizeStart() {},
  onResize: function onResize() {},
  onResizeStop: function onResizeStop() {},
  enable: {
    top: true,
    right: true,
    bottom: true,
    left: true,
    topRight: true,
    bottomRight: true,
    bottomLeft: true,
    topLeft: true
  },
  style: {},
  grid: [1, 1],
  lockAspectRatio: false,
  lockAspectRatioExtraWidth: 0,
  lockAspectRatioExtraHeight: 0
};

var classCallCheck$1 = function (instance, Constructor) {
  if (!(instance instanceof Constructor)) {
    throw new TypeError("Cannot call a class as a function");
  }
};

var createClass$1 = function () {
  function defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];
      descriptor.enumerable = descriptor.enumerable || false;
      descriptor.configurable = true;
      if ("value" in descriptor) descriptor.writable = true;
      Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  return function (Constructor, protoProps, staticProps) {
    if (protoProps) defineProperties(Constructor.prototype, protoProps);
    if (staticProps) defineProperties(Constructor, staticProps);
    return Constructor;
  };
}();

var _extends$1 = Object.assign || function (target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i];

    for (var key in source) {
      if (Object.prototype.hasOwnProperty.call(source, key)) {
        target[key] = source[key];
      }
    }
  }

  return target;
};

var inherits$1 = function (subClass, superClass) {
  if (typeof superClass !== "function" && superClass !== null) {
    throw new TypeError("Super expression must either be null or a function, not " + typeof superClass);
  }

  subClass.prototype = Object.create(superClass && superClass.prototype, {
    constructor: {
      value: subClass,
      enumerable: false,
      writable: true,
      configurable: true
    }
  });
  if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass;
};

var objectWithoutProperties = function (obj, keys) {
  var target = {};

  for (var i in obj) {
    if (keys.indexOf(i) >= 0) continue;
    if (!Object.prototype.hasOwnProperty.call(obj, i)) continue;
    target[i] = obj[i];
  }

  return target;
};

var possibleConstructorReturn$1 = function (self, call) {
  if (!self) {
    throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
  }

  return call && (typeof call === "object" || typeof call === "function") ? call : self;
};

var slicedToArray = function () {
  function sliceIterator(arr, i) {
    var _arr = [];
    var _n = true;
    var _d = false;
    var _e = undefined;

    try {
      for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
        _arr.push(_s.value);

        if (i && _arr.length === i) break;
      }
    } catch (err) {
      _d = true;
      _e = err;
    } finally {
      try {
        if (!_n && _i["return"]) _i["return"]();
      } finally {
        if (_d) throw _e;
      }
    }

    return _arr;
  }

  return function (arr, i) {
    if (Array.isArray(arr)) {
      return arr;
    } else if (Symbol.iterator in Object(arr)) {
      return sliceIterator(arr, i);
    } else {
      throw new TypeError("Invalid attempt to destructure non-iterable instance");
    }
  };
}();

var propTypes = {
    onPixelSizeChange: PropTypes.func,
    minDiff: PropTypes.number
};

/**
 * @abstract
 */

var ResizableElement = function (_React$Component) {
    inherits$1(ResizableElement, _React$Component);

    function ResizableElement() {
        var _ref;

        var _temp, _this, _ret;

        classCallCheck$1(this, ResizableElement);

        for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
            args[_key] = arguments[_key];
        }

        return _ret = (_temp = (_this = possibleConstructorReturn$1(this, (_ref = ResizableElement.__proto__ || Object.getPrototypeOf(ResizableElement)).call.apply(_ref, [this].concat(args))), _this), _this.resizable = null, _this.handleGrow = function () {
            var newWidth = _this.resizable.state.width + _this.props.minDiff;

            _this.resizable.updateSize({
                width: newWidth
            });

            _this.handlePixelSizeChange(newWidth);
        }, _this.handleShrink = function () {
            var newWidth = _this.resizable.state.width - _this.props.minDiff;

            _this.resizable.updateSize({
                width: newWidth
            });

            _this.handlePixelSizeChange(newWidth);
        }, _this.extractRef = function (component) {
            _this.resizable = component;
        }, _this.handlePixelSizeChange = function () {
            var width = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;

            width = typeof width === 'number' ? width : null;

            _this.props.onPixelSizeChange(_this.calculateNewPixelSize(width));
        }, _this.getButtonComponent = function (component, componentProps, handleClick, name) {
            if (component) {
                return React.cloneElement(component, _extends$1({}, component.props, componentProps, { onClick: handleClick }));
            } else {
                return React.createElement(
                    'button',
                    _extends$1({ name: name, onClick: handleClick }, componentProps),
                    '+'
                );
            }
        }, _this.calculateNewPixelSize = function () {

            throw new Error('You have to implement the method `calculateNewPixelSize`!');
        }, _temp), possibleConstructorReturn$1(_this, _ret);
    }

    /**
     * Enlarges the measurement object by given amount of pixels
     */


    /**
     * Shrinks the measurement object by given amount of pixels
     */


    /**
     * Extracts reference to the re-resizable element
     *
     * @param {HTMLDivElement} component
     */


    /**
     * @param {number|*} width - new width to be assumed (if non numeric is given, null will be passed further)
     * Propagate new pixel size
     */


    /**
     * Creates grow/shrink components or uses given one
     *
     * @param {*} component
     * @param {{}} componentProps
     * @param {function} handleClick
     * @param {string} name
     * @returns {*}
     */


    /**
     * Calculates new pixel size
     *
     * @abstract
     * @param {number|null} width - width to be assumed (if null retrieved from re-resizable element)
     * @returns {number}
     */


    return ResizableElement;
}(React.Component);

ResizableElement.propTypes = propTypes;

var _ref =
/*#__PURE__*/
React.createElement("defs", null, React.createElement("linearGradient", {
  y2: 297.014,
  x2: 0,
  y1: 292,
  x1: 0,
  gradientUnits: "userSpaceOnUse",
  id: "a"
}, React.createElement("stop", {
  offset: 0,
  stopColor: "#d2d2d2"
}), React.createElement("stop", {
  offset: 1,
  stopColor: "#fafafa"
})));

var _ref2 =
/*#__PURE__*/
React.createElement("g", {
  transform: "translate(0 -292)"
}, React.createElement("rect", {
  ry: 0,
  y: 292,
  height: 5,
  width: 10,
  fill: "url(#a)",
  fillRule: "evenodd"
}), React.createElement("path", {
  d: "M0 292v5M5 292v3M1 292v2M2 292v2M3 292v2M4 292v2M6 292v2M7 292v2M8 292v2M9 292v2",
  fill: "none",
  stroke: "#000",
  strokeWidth: 0.1
}));

var rulerSvg = "data:image/svg+xml,%3C%3Fxml%20version%3D%221.0%22%20encoding%3D%22UTF-8%22%20standalone%3D%22no%22%3F%3E%3Csvg%20%20%20%20xmlns%3Adc%3D%22http%3A%2F%2Fpurl.org%2Fdc%2Felements%2F1.1%2F%22%20%20%20%20xmlns%3Acc%3D%22http%3A%2F%2Fcreativecommons.org%2Fns%23%22%20%20%20%20xmlns%3Ardf%3D%22http%3A%2F%2Fwww.w3.org%2F1999%2F02%2F22-rdf-syntax-ns%23%22%20%20%20%20xmlns%3Asvg%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%20%20%20%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%20%20%20%20xmlns%3Axlink%3D%22http%3A%2F%2Fwww.w3.org%2F1999%2Fxlink%22%20%20%20%20version%3D%221.1%22%20%20%20%20viewBox%3D%220%200%209.9%205%22%3E%20%20%20%20%3Cdefs%3E%20%20%20%20%20%20%20%20%3ClinearGradient%20%20%20%20%20%20%20%20%20%20%20%20y2%3D%22297.01401%22%20%20%20%20%20%20%20%20%20%20%20%20x2%3D%220%22%20%20%20%20%20%20%20%20%20%20%20%20y1%3D%22292%22%20%20%20%20%20%20%20%20%20%20%20%20x1%3D%220%22%20%20%20%20%20%20%20%20%20%20%20%20gradientUnits%3D%22userSpaceOnUse%22%20%20%20%20%20%20%20%20%20%20%20%20id%3D%22backgroundGradient%22%3E%20%20%20%20%20%20%20%20%20%20%20%20%3Cstop%20offset%3D%220%22%20style%3D%22stop-color%3A%23d2d2d2%3Bstop-opacity%3A1%22%2F%3E%20%20%20%20%20%20%20%20%20%20%20%20%3Cstop%20offset%3D%221%22%20style%3D%22stop-color%3A%23fafafa%3Bstop-opacity%3A1%22%2F%3E%20%20%20%20%20%20%20%20%3C%2FlinearGradient%3E%20%20%20%20%3C%2Fdefs%3E%20%20%20%20%3Cg%20%20%20%20%20%20%20%20transform%3D%22translate%280%2C-291.99998%29%22%20%20%20%20%20%20%20%20id%3D%22layer1%22%3E%20%20%20%20%20%20%20%20%3Crect%20%20%20%20%20%20%20%20%20%20%20%20ry%3D%220%22%20%20%20%20%20%20%20%20%20%20%20%20y%3D%22292%22%20%20%20%20%20%20%20%20%20%20%20%20x%3D%220%22%20%20%20%20%20%20%20%20%20%20%20%20height%3D%225%22%20%20%20%20%20%20%20%20%20%20%20%20width%3D%2210%22%20%20%20%20%20%20%20%20%20%20%20%20style%3D%22fill%3Aurl%28%23backgroundGradient%29%3Bfill-opacity%3A1%3Bfill-rule%3Aevenodd%3Bstroke%3Anone%3Bstroke-width%3A0.28286904%3Bstroke-miterlimit%3A4%3Bstroke-dasharray%3Anone%3Bstroke-opacity%3A1%22%2F%3E%20%20%20%20%20%20%20%20%3Cpath%20%20%20%20%20%20%20%20%20%20%20%20id%3D%22path833%22%20%20%20%20%20%20%20%20%20%20%20%20d%3D%22M%200.0%2C291.99998%20V%20297%22%20%20%20%20%20%20%20%20%20%20%20%20style%3D%22fill%3Anone%3Bstroke%3A%23000000%3Bstroke-width%3A0.1%3Bstroke-linecap%3Abutt%3Bstroke-linejoin%3Amiter%3Bstroke-miterlimit%3A4%3Bstroke-dasharray%3Anone%3Bstroke-opacity%3A1%22%2F%3E%20%20%20%20%20%20%20%20%3Cpath%20%20%20%20%20%20%20%20%20%20%20%20id%3D%22path833-2%22%20%20%20%20%20%20%20%20%20%20%20%20d%3D%22m%205.0%2C292%20v%203%22%20%20%20%20%20%20%20%20%20%20%20%20style%3D%22fill%3Anone%3Bstroke%3A%23000000%3Bstroke-width%3A0.10000001%3Bstroke-linecap%3Abutt%3Bstroke-linejoin%3Amiter%3Bstroke-miterlimit%3A4%3Bstroke-dasharray%3Anone%3Bstroke-opacity%3A1%22%2F%3E%20%20%20%20%20%20%20%20%3Cpath%20%20%20%20%20%20%20%20%20%20%20%20id%3D%22path833-2-9%22%20%20%20%20%20%20%20%20%20%20%20%20d%3D%22m%201.0%2C292%20v%202%22%20%20%20%20%20%20%20%20%20%20%20%20style%3D%22fill%3Anone%3Bstroke%3A%23000000%3Bstroke-width%3A0.1%3Bstroke-linecap%3Abutt%3Bstroke-linejoin%3Amiter%3Bstroke-miterlimit%3A4%3Bstroke-dasharray%3Anone%3Bstroke-opacity%3A1%22%2F%3E%20%20%20%20%20%20%20%20%3Cpath%20%20%20%20%20%20%20%20%20%20%20%20id%3D%22path833-2-9-3%22%20%20%20%20%20%20%20%20%20%20%20%20d%3D%22m%202.0%2C292%20v%202%22%20%20%20%20%20%20%20%20%20%20%20%20style%3D%22fill%3Anone%3Bstroke%3A%23000000%3Bstroke-width%3A0.1%3Bstroke-linecap%3Abutt%3Bstroke-linejoin%3Amiter%3Bstroke-miterlimit%3A4%3Bstroke-dasharray%3Anone%3Bstroke-opacity%3A1%22%2F%3E%20%20%20%20%20%20%20%20%3Cpath%20%20%20%20%20%20%20%20%20%20%20%20id%3D%22path833-2-9-3-6%22%20%20%20%20%20%20%20%20%20%20%20%20d%3D%22m%203.0%2C292%20v%202%22%20%20%20%20%20%20%20%20%20%20%20%20style%3D%22fill%3Anone%3Bstroke%3A%23000000%3Bstroke-width%3A0.1%3Bstroke-linecap%3Abutt%3Bstroke-linejoin%3Amiter%3Bstroke-miterlimit%3A4%3Bstroke-dasharray%3Anone%3Bstroke-opacity%3A1%22%2F%3E%20%20%20%20%20%20%20%20%3Cpath%20%20%20%20%20%20%20%20%20%20%20%20id%3D%22path833-2-9-3-6-8%22%20%20%20%20%20%20%20%20%20%20%20%20d%3D%22m%204.0%2C292%20v%202%22%20%20%20%20%20%20%20%20%20%20%20%20style%3D%22fill%3Anone%3Bstroke%3A%23000000%3Bstroke-width%3A0.1%3Bstroke-linecap%3Abutt%3Bstroke-linejoin%3Amiter%3Bstroke-miterlimit%3A4%3Bstroke-dasharray%3Anone%3Bstroke-opacity%3A1%22%2F%3E%20%20%20%20%20%20%20%20%3Cpath%20%20%20%20%20%20%20%20%20%20%20%20id%3D%22path833-2-9-3-6-8-0%22%20%20%20%20%20%20%20%20%20%20%20%20d%3D%22m%206.0%2C292%20v%202%22%20%20%20%20%20%20%20%20%20%20%20%20style%3D%22fill%3Anone%3Bstroke%3A%23000000%3Bstroke-width%3A0.1%3Bstroke-linecap%3Abutt%3Bstroke-linejoin%3Amiter%3Bstroke-miterlimit%3A4%3Bstroke-dasharray%3Anone%3Bstroke-opacity%3A1%22%2F%3E%20%20%20%20%20%20%20%20%3Cpath%20%20%20%20%20%20%20%20%20%20%20%20id%3D%22path833-2-9-3-6-8-0-2%22%20%20%20%20%20%20%20%20%20%20%20%20d%3D%22m%207.0%2C292%20v%202%22%20%20%20%20%20%20%20%20%20%20%20%20style%3D%22fill%3Anone%3Bstroke%3A%23000000%3Bstroke-width%3A0.1%3Bstroke-linecap%3Abutt%3Bstroke-linejoin%3Amiter%3Bstroke-miterlimit%3A4%3Bstroke-dasharray%3Anone%3Bstroke-opacity%3A1%22%2F%3E%20%20%20%20%20%20%20%20%3Cpath%20%20%20%20%20%20%20%20%20%20%20%20id%3D%22path833-2-9-3-6-8-0-2-1%22%20%20%20%20%20%20%20%20%20%20%20%20d%3D%22m%208.0%2C292%20v%202%22%20%20%20%20%20%20%20%20%20%20%20%20style%3D%22fill%3Anone%3Bstroke%3A%23000000%3Bstroke-width%3A0.1%3Bstroke-linecap%3Abutt%3Bstroke-linejoin%3Amiter%3Bstroke-miterlimit%3A4%3Bstroke-dasharray%3Anone%3Bstroke-opacity%3A1%22%2F%3E%20%20%20%20%20%20%20%20%3Cpath%20%20%20%20%20%20%20%20%20%20%20%20id%3D%22path833-2-9-3-6-8-0-2-1-0%22%20%20%20%20%20%20%20%20%20%20%20%20d%3D%22m%209.0%2C292%20v%202%22%20%20%20%20%20%20%20%20%20%20%20%20style%3D%22fill%3Anone%3Bstroke%3A%23000000%3Bstroke-width%3A0.1%3Bstroke-linecap%3Abutt%3Bstroke-linejoin%3Amiter%3Bstroke-miterlimit%3A4%3Bstroke-dasharray%3Anone%3Bstroke-opacity%3A1%22%2F%3E%20%20%20%20%3C%2Fg%3E%3C%2Fsvg%3E";

var _ref$1 =
/*#__PURE__*/
React.createElement("defs", null, React.createElement("linearGradient", {
  y2: 297.014,
  x2: 0,
  y1: 292,
  x1: 0,
  gradientUnits: "userSpaceOnUse",
  id: "a"
}, React.createElement("stop", {
  offset: 0,
  stopColor: "#d2d2d2"
}), React.createElement("stop", {
  offset: 1,
  stopColor: "#fafafa"
})));

var _ref2$1 =
/*#__PURE__*/
React.createElement("g", {
  transform: "translate(0 -292)"
}, React.createElement("rect", {
  ry: 0,
  y: 292,
  height: 5,
  width: 10,
  fill: "url(#a)",
  fillRule: "evenodd"
}), React.createElement("path", {
  d: "M.05 292v5M5 292v3M1 292v2M2 292v2M3 292v2M4 292v2M6 292v2M7 292v2M8 292v2M9 292v2M9.95 292v5",
  fill: "none",
  stroke: "#000",
  strokeWidth: 0.1
}));

var rulerEndSvg = "data:image/svg+xml,%3C%3Fxml%20version%3D%221.0%22%20encoding%3D%22UTF-8%22%20standalone%3D%22no%22%3F%3E%3Csvg%20%20%20%20xmlns%3Adc%3D%22http%3A%2F%2Fpurl.org%2Fdc%2Felements%2F1.1%2F%22%20%20%20%20xmlns%3Acc%3D%22http%3A%2F%2Fcreativecommons.org%2Fns%23%22%20%20%20%20xmlns%3Ardf%3D%22http%3A%2F%2Fwww.w3.org%2F1999%2F02%2F22-rdf-syntax-ns%23%22%20%20%20%20xmlns%3Asvg%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%20%20%20%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%20%20%20%20xmlns%3Axlink%3D%22http%3A%2F%2Fwww.w3.org%2F1999%2Fxlink%22%20%20%20%20version%3D%221.1%22%20%20%20%20viewBox%3D%220%200%2010%205%22%3E%20%20%20%20%3Cdefs%3E%20%20%20%20%20%20%20%20%3ClinearGradient%20%20%20%20%20%20%20%20%20%20%20%20y2%3D%22297.01401%22%20%20%20%20%20%20%20%20%20%20%20%20x2%3D%220%22%20%20%20%20%20%20%20%20%20%20%20%20y1%3D%22292%22%20%20%20%20%20%20%20%20%20%20%20%20x1%3D%220%22%20%20%20%20%20%20%20%20%20%20%20%20gradientUnits%3D%22userSpaceOnUse%22%20%20%20%20%20%20%20%20%20%20%20%20id%3D%22backgroundGradient%22%3E%20%20%20%20%20%20%20%20%20%20%20%20%3Cstop%20offset%3D%220%22%20style%3D%22stop-color%3A%23d2d2d2%3Bstop-opacity%3A1%22%2F%3E%20%20%20%20%20%20%20%20%20%20%20%20%3Cstop%20offset%3D%221%22%20style%3D%22stop-color%3A%23fafafa%3Bstop-opacity%3A1%22%2F%3E%20%20%20%20%20%20%20%20%3C%2FlinearGradient%3E%20%20%20%20%3C%2Fdefs%3E%20%20%20%20%3Cg%20%20%20%20%20%20%20%20transform%3D%22translate%280%2C-291.99998%29%22%20%20%20%20%20%20%20%20id%3D%22layer1%22%3E%20%20%20%20%20%20%20%20%3Crect%20%20%20%20%20%20%20%20%20%20%20%20ry%3D%220%22%20%20%20%20%20%20%20%20%20%20%20%20y%3D%22292%22%20%20%20%20%20%20%20%20%20%20%20%20x%3D%220%22%20%20%20%20%20%20%20%20%20%20%20%20height%3D%225%22%20%20%20%20%20%20%20%20%20%20%20%20width%3D%2210%22%20%20%20%20%20%20%20%20%20%20%20%20style%3D%22fill%3Aurl%28%23backgroundGradient%29%3Bfill-opacity%3A1%3Bfill-rule%3Aevenodd%3Bstroke%3Anone%3Bstroke-width%3A0.28286904%3Bstroke-miterlimit%3A4%3Bstroke-dasharray%3Anone%3Bstroke-opacity%3A1%22%2F%3E%20%20%20%20%20%20%20%20%3Cpath%20%20%20%20%20%20%20%20%20%20%20%20id%3D%22path833%22%20%20%20%20%20%20%20%20%20%20%20%20d%3D%22M%200.05%2C291.99998%20V%20297%22%20%20%20%20%20%20%20%20%20%20%20%20style%3D%22fill%3Anone%3Bstroke%3A%23000000%3Bstroke-width%3A0.1%3Bstroke-linecap%3Abutt%3Bstroke-linejoin%3Amiter%3Bstroke-miterlimit%3A4%3Bstroke-dasharray%3Anone%3Bstroke-opacity%3A1%22%2F%3E%20%20%20%20%20%20%20%20%3Cpath%20%20%20%20%20%20%20%20%20%20%20%20id%3D%22path833-2%22%20%20%20%20%20%20%20%20%20%20%20%20d%3D%22m%205.0%2C292%20v%203%22%20%20%20%20%20%20%20%20%20%20%20%20style%3D%22fill%3Anone%3Bstroke%3A%23000000%3Bstroke-width%3A0.10000001%3Bstroke-linecap%3Abutt%3Bstroke-linejoin%3Amiter%3Bstroke-miterlimit%3A4%3Bstroke-dasharray%3Anone%3Bstroke-opacity%3A1%22%2F%3E%20%20%20%20%20%20%20%20%3Cpath%20%20%20%20%20%20%20%20%20%20%20%20id%3D%22path833-2-9%22%20%20%20%20%20%20%20%20%20%20%20%20d%3D%22m%201.0%2C292%20v%202%22%20%20%20%20%20%20%20%20%20%20%20%20style%3D%22fill%3Anone%3Bstroke%3A%23000000%3Bstroke-width%3A0.1%3Bstroke-linecap%3Abutt%3Bstroke-linejoin%3Amiter%3Bstroke-miterlimit%3A4%3Bstroke-dasharray%3Anone%3Bstroke-opacity%3A1%22%2F%3E%20%20%20%20%20%20%20%20%3Cpath%20%20%20%20%20%20%20%20%20%20%20%20id%3D%22path833-2-9-3%22%20%20%20%20%20%20%20%20%20%20%20%20d%3D%22m%202.0%2C292%20v%202%22%20%20%20%20%20%20%20%20%20%20%20%20style%3D%22fill%3Anone%3Bstroke%3A%23000000%3Bstroke-width%3A0.1%3Bstroke-linecap%3Abutt%3Bstroke-linejoin%3Amiter%3Bstroke-miterlimit%3A4%3Bstroke-dasharray%3Anone%3Bstroke-opacity%3A1%22%2F%3E%20%20%20%20%20%20%20%20%3Cpath%20%20%20%20%20%20%20%20%20%20%20%20id%3D%22path833-2-9-3-6%22%20%20%20%20%20%20%20%20%20%20%20%20d%3D%22m%203.0%2C292%20v%202%22%20%20%20%20%20%20%20%20%20%20%20%20style%3D%22fill%3Anone%3Bstroke%3A%23000000%3Bstroke-width%3A0.1%3Bstroke-linecap%3Abutt%3Bstroke-linejoin%3Amiter%3Bstroke-miterlimit%3A4%3Bstroke-dasharray%3Anone%3Bstroke-opacity%3A1%22%2F%3E%20%20%20%20%20%20%20%20%3Cpath%20%20%20%20%20%20%20%20%20%20%20%20id%3D%22path833-2-9-3-6-8%22%20%20%20%20%20%20%20%20%20%20%20%20d%3D%22m%204.0%2C292%20v%202%22%20%20%20%20%20%20%20%20%20%20%20%20style%3D%22fill%3Anone%3Bstroke%3A%23000000%3Bstroke-width%3A0.1%3Bstroke-linecap%3Abutt%3Bstroke-linejoin%3Amiter%3Bstroke-miterlimit%3A4%3Bstroke-dasharray%3Anone%3Bstroke-opacity%3A1%22%2F%3E%20%20%20%20%20%20%20%20%3Cpath%20%20%20%20%20%20%20%20%20%20%20%20id%3D%22path833-2-9-3-6-8-0%22%20%20%20%20%20%20%20%20%20%20%20%20d%3D%22m%206.0%2C292%20v%202%22%20%20%20%20%20%20%20%20%20%20%20%20style%3D%22fill%3Anone%3Bstroke%3A%23000000%3Bstroke-width%3A0.1%3Bstroke-linecap%3Abutt%3Bstroke-linejoin%3Amiter%3Bstroke-miterlimit%3A4%3Bstroke-dasharray%3Anone%3Bstroke-opacity%3A1%22%2F%3E%20%20%20%20%20%20%20%20%3Cpath%20%20%20%20%20%20%20%20%20%20%20%20id%3D%22path833-2-9-3-6-8-0-2%22%20%20%20%20%20%20%20%20%20%20%20%20d%3D%22m%207.0%2C292%20v%202%22%20%20%20%20%20%20%20%20%20%20%20%20style%3D%22fill%3Anone%3Bstroke%3A%23000000%3Bstroke-width%3A0.1%3Bstroke-linecap%3Abutt%3Bstroke-linejoin%3Amiter%3Bstroke-miterlimit%3A4%3Bstroke-dasharray%3Anone%3Bstroke-opacity%3A1%22%2F%3E%20%20%20%20%20%20%20%20%3Cpath%20%20%20%20%20%20%20%20%20%20%20%20id%3D%22path833-2-9-3-6-8-0-2-1%22%20%20%20%20%20%20%20%20%20%20%20%20d%3D%22m%208.0%2C292%20v%202%22%20%20%20%20%20%20%20%20%20%20%20%20style%3D%22fill%3Anone%3Bstroke%3A%23000000%3Bstroke-width%3A0.1%3Bstroke-linecap%3Abutt%3Bstroke-linejoin%3Amiter%3Bstroke-miterlimit%3A4%3Bstroke-dasharray%3Anone%3Bstroke-opacity%3A1%22%2F%3E%20%20%20%20%20%20%20%20%3Cpath%20%20%20%20%20%20%20%20%20%20%20%20id%3D%22path833-2-9-3-6-8-0-2-1-0%22%20%20%20%20%20%20%20%20%20%20%20%20d%3D%22m%209.0%2C292%20v%202%22%20%20%20%20%20%20%20%20%20%20%20%20style%3D%22fill%3Anone%3Bstroke%3A%23000000%3Bstroke-width%3A0.1%3Bstroke-linecap%3Abutt%3Bstroke-linejoin%3Amiter%3Bstroke-miterlimit%3A4%3Bstroke-dasharray%3Anone%3Bstroke-opacity%3A1%22%2F%3E%20%20%20%20%20%20%20%20%3Cpath%20%20%20%20%20%20%20%20%20%20%20%20id%3D%22path833%22%20%20%20%20%20%20%20%20%20%20%20%20d%3D%22M%209.95%2C291.99998%20V%20297%22%20%20%20%20%20%20%20%20%20%20%20%20style%3D%22fill%3Anone%3Bstroke%3A%23000000%3Bstroke-width%3A0.1%3Bstroke-linecap%3Abutt%3Bstroke-linejoin%3Amiter%3Bstroke-miterlimit%3A4%3Bstroke-dasharray%3Anone%3Bstroke-opacity%3A1%22%2F%3E%20%20%20%20%3C%2Fg%3E%3C%2Fsvg%3E";

var propTypes$1 = {
    length: PropTypes.number
};

var defaultProps = {
    length: 3
};

var Ruler = function (_React$Component) {
    inherits$1(Ruler, _React$Component);

    function Ruler() {
        classCallCheck$1(this, Ruler);
        return possibleConstructorReturn$1(this, (Ruler.__proto__ || Object.getPrototypeOf(Ruler)).apply(this, arguments));
    }

    createClass$1(Ruler, [{
        key: 'render',
        value: function render() {
            var length = this.props.length;


            return React.createElement(
                'div',
                { style: { display: 'flex' } },
                Ruler.buildRuler(length)
            );
        }
    }]);
    return Ruler;
}(React.Component);

Ruler.buildRuler = function (length) {
    var rulerElements = [];

    for (var i = 0; i < length - 1; i++) {
        rulerElements.push(React.createElement('img', { key: i, alt: '', src: rulerSvg }));
    }

    rulerElements.push(React.createElement('img', { key: length - 1, alt: '', src: rulerEndSvg }));

    return rulerElements;
};

Ruler.defaultProps = defaultProps;
Ruler.propTypes = propTypes$1;

var propTypes$2 = {
    onPixelSizeChange: PropTypes.func,
    minDiff: PropTypes.number,
    rulerLength: PropTypes.number,
    growComponentProps: PropTypes.object,
    shrinkComponentProps: PropTypes.object,
    growComponent: PropTypes.element,
    shrinkComponent: PropTypes.element
};

var defaultProps$1 = {
    onPixelSizeChange: function onPixelSizeChange() {},
    minDiff: 1,
    rulerLength: 3
};

var RulerPixelSize = function (_ResizableElement) {
    inherits$1(RulerPixelSize, _ResizableElement);

    function RulerPixelSize() {
        var _ref;

        var _temp, _this, _ret;

        classCallCheck$1(this, RulerPixelSize);

        for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
            args[_key] = arguments[_key];
        }

        return _ret = (_temp = (_this = possibleConstructorReturn$1(this, (_ref = RulerPixelSize.__proto__ || Object.getPrototypeOf(RulerPixelSize)).call.apply(_ref, [this].concat(args))), _this), _this.calculateNewPixelSize = function () {
            var width = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;

            return _this.props.rulerLength * 10000 / (width === null ? _this.resizable.state.width : width);
        }, _temp), possibleConstructorReturn$1(_this, _ret);
    }

    createClass$1(RulerPixelSize, [{
        key: 'componentDidMount',
        value: function componentDidMount() {
            this.handlePixelSizeChange(50 * this.props.rulerLength);
        }
    }, {
        key: 'render',
        value: function render() {
            var _props = this.props,
                growComponentProps = _props.growComponentProps,
                shrinkComponentProps = _props.shrinkComponentProps,
                buttonsProps = _props.buttonsProps,
                growComponent = _props.growComponent,
                shrinkComponent = _props.shrinkComponent,
                rulerLength = _props.rulerLength,
                minDiff = _props.minDiff,
                onPixelSizeChange = _props.onPixelSizeChange,
                other = objectWithoutProperties(_props, ['growComponentProps', 'shrinkComponentProps', 'buttonsProps', 'growComponent', 'shrinkComponent', 'rulerLength', 'minDiff', 'onPixelSizeChange']);


            var grow = this.getButtonComponent(growComponent, growComponentProps, this.handleGrow, 'grow');
            var shrink = this.getButtonComponent(shrinkComponent, shrinkComponentProps, this.handleShrink, 'shrink');

            return React.createElement(
                'div',
                other,
                React.createElement(
                    Resizable,
                    {
                        defaultSize: {
                            width: 50 * rulerLength,
                            height: '100%'
                        },
                        onResize: this.handlePixelSizeChange,
                        ref: this.extractRef
                    },
                    React.createElement(Ruler, { style: { width: '100%' }, length: rulerLength })
                ),
                React.createElement(
                    'div',
                    buttonsProps,
                    grow,
                    shrink
                )
            );
        }
    }]);
    return RulerPixelSize;
}(ResizableElement);

RulerPixelSize.propTypes = propTypes$2;
RulerPixelSize.defaultProps = defaultProps$1;

var cardPaths = {
    number: ['m 6.3818313,276.88323 q 0.3958167,-0.15522 0.76835,-0.38805 0.3725333,-0.2406 0.6907389,-0.60537 h 0.4501445 v 4.26085 h 0.90805 v 0.54328 H 6.6146646 v -0.54328 h 1.0399889 v -3.36832 q -0.085372,0.0776 -0.20955,0.16298 -0.1164166,0.0776 -0.2638778,0.15522 -0.1397,0.0776 -0.2949222,0.14747 -0.1552222,0.0698 -0.3026833,0.11641 z', 'm 12.93997,277.11607 q 0,0.24835 -0.100894,0.48119 -0.09313,0.23283 -0.256117,0.4579 -0.155222,0.22507 -0.357011,0.44238 -0.201789,0.21732 -0.411339,0.42687 -0.116416,0.11641 -0.271639,0.2794 -0.155222,0.16298 -0.294922,0.33372 -0.1397,0.17075 -0.232833,0.33373 -0.09313,0.16298 -0.09313,0.2794 h 2.211917 v 0.54328 h -2.910417 q -0.0078,-0.0388 -0.0078,-0.0776 0,-0.0466 0,-0.0854 0,-0.32597 0.108656,-0.60537 0.108655,-0.2794 0.2794,-0.52776 0.170744,-0.24835 0.380294,-0.46566 0.217311,-0.22508 0.426861,-0.43463 0.170745,-0.17074 0.325967,-0.33372 0.162983,-0.16299 0.2794,-0.32597 0.124178,-0.16298 0.194028,-0.33373 0.07761,-0.1785 0.07761,-0.36477 0,-0.20955 -0.06985,-0.35701 -0.06209,-0.14746 -0.178506,-0.2406 -0.108655,-0.10089 -0.256116,-0.14746 -0.147461,-0.0466 -0.318206,-0.0466 -0.201789,0 -0.372533,0.0543 -0.162984,0.0543 -0.294922,0.13194 -0.124178,0.0776 -0.217312,0.15523 -0.09313,0.0698 -0.1397,0.11641 l -0.318205,-0.45014 q 0.06209,-0.0698 0.186267,-0.17075 0.124177,-0.10089 0.294922,-0.18626 0.178505,-0.0931 0.395816,-0.15523 0.217312,-0.0621 0.465667,-0.0621 0.752828,0 1.109839,0.34925 0.364772,0.34148 0.364772,0.98566 z', 'm 15.206215,280.22827 q 0.613128,0 0.869244,-0.24059 0.263878,-0.24836 0.263878,-0.6597 0,-0.26387 -0.108656,-0.44238 -0.108655,-0.17851 -0.287161,-0.28716 -0.178505,-0.10866 -0.411339,-0.15522 -0.232833,-0.0466 -0.48895,-0.0466 h -0.162983 v -0.51999 h 0.225072 q 0.170745,0 0.34925,-0.031 0.186267,-0.0388 0.333728,-0.12418 0.155222,-0.0931 0.248356,-0.24835 0.09313,-0.15522 0.09313,-0.39582 0,-0.39582 -0.248356,-0.5588 -0.240594,-0.17074 -0.566561,-0.17074 -0.333727,0 -0.566561,0.10089 -0.232833,0.0931 -0.388055,0.19403 l -0.248356,-0.48895 q 0.162983,-0.11642 0.48895,-0.2406 0.333728,-0.13193 0.737306,-0.13193 0.380294,0 0.651933,0.0931 0.271639,0.0931 0.442383,0.26388 0.178506,0.17074 0.263878,0.40357 0.08537,0.22508 0.08537,0.49672 0,0.38029 -0.201789,0.64417 -0.194027,0.26388 -0.504472,0.40358 0.372534,0.10865 0.644172,0.42686 0.271639,0.31044 0.271639,0.83044 0,0.31044 -0.108655,0.58208 -0.100895,0.26388 -0.318206,0.4579 -0.20955,0.19403 -0.551039,0.30269 -0.333727,0.10865 -0.799394,0.10865 -0.178506,0 -0.372533,-0.031 -0.186267,-0.0233 -0.34925,-0.0698 -0.162984,-0.0388 -0.294923,-0.0776 -0.124177,-0.0466 -0.178505,-0.0699 l 0.124178,-0.55104 q 0.124177,0.0621 0.395816,0.14746 0.271639,0.0854 0.667456,0.0854 z', 'm 17.720814,279.03306 q 0.131939,-0.31044 0.357011,-0.71402 0.232834,-0.40358 0.519995,-0.83044 0.287161,-0.43462 0.613128,-0.84596 0.325966,-0.4191 0.659694,-0.75283 h 0.620889 v 3.05012 h 0.566561 v 0.52775 h -0.566561 v 1.22626 h -0.620889 v -1.22626 h -2.149828 z m 2.149828,-2.38266 q -0.20955,0.22507 -0.426861,0.49671 -0.20955,0.27164 -0.411339,0.57432 -0.201789,0.29493 -0.380294,0.60537 -0.170745,0.31044 -0.310445,0.61313 h 1.528939 z', 'm 26.646093,277.74472 q 1.039989,0.0388 1.513417,0.4579 0.473428,0.4191 0.473428,1.12536 0,0.31821 -0.100895,0.58985 -0.100894,0.27164 -0.318205,0.46566 -0.20955,0.19403 -0.543278,0.30269 -0.325967,0.10865 -0.776111,0.10865 -0.186267,0 -0.372534,-0.031 -0.178505,-0.0233 -0.341488,-0.0621 -0.162984,-0.0388 -0.287162,-0.0776 -0.124177,-0.0466 -0.178505,-0.0776 l 0.124178,-0.55104 q 0.124177,0.0621 0.380294,0.14746 0.263878,0.0854 0.659695,0.0854 0.310444,0 0.519994,-0.0699 0.20955,-0.0698 0.333728,-0.18626 0.131939,-0.12418 0.186267,-0.2794 0.06209,-0.15523 0.06209,-0.32597 0,-0.26388 -0.09313,-0.46567 -0.08537,-0.20955 -0.310444,-0.34925 -0.217312,-0.1397 -0.605367,-0.20955 -0.380295,-0.0776 -0.962378,-0.0776 0.04657,-0.34149 0.06985,-0.63641 0.03104,-0.30268 0.04657,-0.58208 0.02328,-0.28716 0.03104,-0.56656 0.01552,-0.2794 0.03104,-0.58985 h 2.312811 v 0.54328 h -1.754011 q -0.0078,0.10865 -0.02328,0.28716 -0.0078,0.17074 -0.02328,0.36477 -0.01552,0.19403 -0.03104,0.37254 -0.01552,0.1785 -0.02328,0.28716 z', 'm 29.502181,278.76918 q 0,-0.6985 0.186266,-1.23401 0.194028,-0.54328 0.543278,-0.90805 0.357011,-0.36478 0.861484,-0.5588 0.504472,-0.19403 1.140883,-0.20179 l 0.05433,0.54328 q -0.411339,0.008 -0.752828,0.0931 -0.333728,0.0776 -0.597606,0.26388 -0.263877,0.1785 -0.442383,0.46566 -0.178506,0.28716 -0.271639,0.70626 0.186267,-0.0854 0.403578,-0.1397 0.225072,-0.0543 0.473428,-0.0543 0.403577,0 0.682977,0.12417 0.287162,0.12418 0.457906,0.33373 0.170744,0.20179 0.248356,0.47343 0.07761,0.27164 0.07761,0.5588 0,0.26388 -0.08537,0.54328 -0.08537,0.27164 -0.263878,0.50447 -0.178506,0.22507 -0.457906,0.37253 -0.2794,0.1397 -0.667455,0.1397 -0.799395,0 -1.195212,-0.53551 -0.395816,-0.53552 -0.395816,-1.49014 z m 1.528939,-0.49671 q -0.248356,0 -0.457906,0.0466 -0.201789,0.0466 -0.411339,0.1397 -0.0078,0.0776 -0.0078,0.15522 0,0.0698 0,0.15522 0,0.30269 0.03881,0.57433 0.04657,0.26387 0.147461,0.47342 0.108655,0.20179 0.287161,0.32597 0.178505,0.11642 0.457905,0.11642 0.232834,0 0.388056,-0.0931 0.155222,-0.10089 0.256117,-0.24835 0.100894,-0.14746 0.1397,-0.32597 0.04657,-0.18627 0.04657,-0.34925 0,-0.47343 -0.217311,-0.72178 -0.20955,-0.24836 -0.667455,-0.24836 z', 'm 34.166609,280.69394 q 0.03881,-0.55104 0.194028,-1.16417 0.162983,-0.62089 0.388055,-1.19521 0.225073,-0.58208 0.496712,-1.07103 0.271638,-0.49671 0.535516,-0.81492 h -2.328333 v -0.5588 h 3.042355 v 0.53552 q -0.232833,0.27164 -0.504472,0.72954 -0.271639,0.45791 -0.519994,1.03223 -0.240595,0.56656 -0.4191,1.21849 -0.178506,0.64418 -0.225072,1.28835 z', 'm 40.328932,279.4444 q 0,0.60537 -0.388056,0.9779 -0.380294,0.37253 -1.164166,0.37253 -0.450145,0 -0.745067,-0.11641 -0.294922,-0.12418 -0.473428,-0.31045 -0.170744,-0.19403 -0.248355,-0.42686 -0.06985,-0.23283 -0.06985,-0.4579 0,-0.41134 0.225072,-0.72955 0.225072,-0.3182 0.535517,-0.51223 -0.659695,-0.37254 -0.659695,-1.14089 0,-0.26387 0.100895,-0.50447 0.100894,-0.24059 0.287161,-0.4191 0.186266,-0.1785 0.450144,-0.28716 0.271639,-0.10865 0.605367,-0.10865 0.388055,0 0.659694,0.11641 0.2794,0.11642 0.450145,0.30269 0.170744,0.1785 0.248355,0.40357 0.07761,0.21731 0.07761,0.42686 0,0.41134 -0.20955,0.71403 -0.20955,0.29492 -0.481189,0.47342 0.799395,0.3803 0.799395,1.22626 z m -2.468033,0.0466 q 0,0.12417 0.04657,0.26387 0.04657,0.13194 0.155222,0.24836 0.108656,0.11642 0.287162,0.19403 0.178505,0.0699 0.434622,0.0699 0.240594,0 0.411339,-0.0621 0.178505,-0.0699 0.287161,-0.17851 0.116416,-0.11641 0.170744,-0.25611 0.05433,-0.1397 0.05433,-0.2794 0,-0.44239 -0.318206,-0.67522 -0.318205,-0.24059 -0.877005,-0.36477 -0.310445,0.17074 -0.481189,0.42686 -0.170744,0.25612 -0.170744,0.61313 z m 1.738488,-2.46028 q 0,-0.10089 -0.04657,-0.22507 -0.04657,-0.13194 -0.147461,-0.23283 -0.09313,-0.10866 -0.248356,-0.17851 -0.155222,-0.0776 -0.372533,-0.0776 -0.225072,0 -0.380295,0.0699 -0.147461,0.0698 -0.248355,0.17851 -0.100895,0.10089 -0.147461,0.23283 -0.03881,0.12418 -0.03881,0.24836 0,0.3182 0.225072,0.5976 0.232834,0.27164 0.760589,0.39582 0.294922,-0.17075 0.465667,-0.40358 0.178505,-0.23283 0.178505,-0.60537 z', 'm 45.187389,276.88323 q 0.395816,-0.15522 0.76835,-0.38805 0.372533,-0.2406 0.690738,-0.60537 h 0.450145 v 4.26085 h 0.90805 v 0.54328 h -2.58445 v -0.54328 h 1.039989 v -3.36832 q -0.08537,0.0776 -0.20955,0.16298 -0.116417,0.0776 -0.263878,0.15522 -0.1397,0.0776 -0.294922,0.14747 -0.155222,0.0698 -0.302684,0.11641 z', 'm 51.745526,277.11607 q 0,0.24835 -0.100894,0.48119 -0.09313,0.23283 -0.256117,0.4579 -0.155222,0.22507 -0.357011,0.44238 -0.201789,0.21732 -0.411339,0.42687 -0.116417,0.11641 -0.271639,0.2794 -0.155222,0.16298 -0.294922,0.33372 -0.1397,0.17075 -0.232833,0.33373 -0.09313,0.16298 -0.09313,0.2794 h 2.211917 v 0.54328 h -2.910417 q -0.0078,-0.0388 -0.0078,-0.0776 0,-0.0466 0,-0.0854 0,-0.32597 0.108656,-0.60537 0.108655,-0.2794 0.2794,-0.52776 0.170744,-0.24835 0.380294,-0.46566 0.217311,-0.22508 0.426861,-0.43463 0.170745,-0.17074 0.325967,-0.33372 0.162983,-0.16299 0.2794,-0.32597 0.124178,-0.16298 0.194028,-0.33373 0.07761,-0.1785 0.07761,-0.36477 0,-0.20955 -0.06985,-0.35701 -0.06209,-0.14746 -0.178506,-0.2406 -0.108655,-0.10089 -0.256116,-0.14746 -0.147462,-0.0466 -0.318206,-0.0466 -0.201789,0 -0.372533,0.0543 -0.162984,0.0543 -0.294923,0.13194 -0.124177,0.0776 -0.217311,0.15523 -0.09313,0.0698 -0.1397,0.11641 l -0.318205,-0.45014 q 0.06209,-0.0698 0.186266,-0.17075 0.124178,-0.10089 0.294923,-0.18626 0.178505,-0.0931 0.395816,-0.15523 0.217311,-0.0621 0.465667,-0.0621 0.752828,0 1.109839,0.34925 0.364772,0.34148 0.364772,0.98566 z', 'm 54.011769,280.22827 q 0.613128,0 0.869245,-0.24059 0.263877,-0.24836 0.263877,-0.6597 0,-0.26387 -0.108655,-0.44238 -0.108656,-0.17851 -0.287161,-0.28716 -0.178506,-0.10866 -0.411339,-0.15522 -0.232833,-0.0466 -0.48895,-0.0466 h -0.162983 v -0.51999 h 0.225072 q 0.170744,0 0.34925,-0.031 0.186266,-0.0388 0.333728,-0.12418 0.155222,-0.0931 0.248355,-0.24835 0.09313,-0.15522 0.09313,-0.39582 0,-0.39582 -0.248355,-0.5588 -0.240595,-0.17074 -0.566561,-0.17074 -0.333728,0 -0.566561,0.10089 -0.232834,0.0931 -0.388056,0.19403 l -0.248356,-0.48895 q 0.162984,-0.11642 0.488951,-0.2406 0.333727,-0.13193 0.737305,-0.13193 0.380295,0 0.651933,0.0931 0.271639,0.0931 0.442384,0.26388 0.178505,0.17074 0.263878,0.40357 0.08537,0.22508 0.08537,0.49672 0,0.38029 -0.201789,0.64417 -0.194028,0.26388 -0.504472,0.40358 0.372533,0.10865 0.644172,0.42686 0.271639,0.31044 0.271639,0.83044 0,0.31044 -0.108656,0.58208 -0.100894,0.26388 -0.318205,0.4579 -0.20955,0.19403 -0.551039,0.30269 -0.333728,0.10865 -0.799395,0.10865 -0.178505,0 -0.372533,-0.031 -0.186267,-0.0233 -0.34925,-0.0698 -0.162983,-0.0388 -0.294922,-0.0776 -0.124178,-0.0466 -0.178506,-0.0699 l 0.124178,-0.55104 q 0.124178,0.0621 0.395817,0.14746 0.271639,0.0854 0.667455,0.0854 z', 'm 56.526372,279.03306 q 0.131939,-0.31044 0.357011,-0.71402 0.232833,-0.40358 0.519994,-0.83044 0.287161,-0.43462 0.613128,-0.84596 0.325967,-0.4191 0.659694,-0.75283 h 0.620889 v 3.05012 h 0.566561 v 0.52775 h -0.566561 v 1.22626 h -0.620889 v -1.22626 h -2.149827 z m 2.149827,-2.38266 q -0.20955,0.22507 -0.426861,0.49671 -0.20955,0.27164 -0.411339,0.57432 -0.201788,0.29493 -0.380294,0.60537 -0.170744,0.31044 -0.310444,0.61313 h 1.528938 z', 'm 65.451651,277.74472 q 1.039988,0.0388 1.513416,0.4579 0.473428,0.4191 0.473428,1.12536 0,0.31821 -0.100894,0.58985 -0.100895,0.27164 -0.318206,0.46566 -0.20955,0.19403 -0.543278,0.30269 -0.325966,0.10865 -0.776111,0.10865 -0.186267,0 -0.372533,-0.031 -0.178506,-0.0233 -0.341489,-0.0621 -0.162983,-0.0388 -0.287161,-0.0776 -0.124178,-0.0466 -0.178506,-0.0776 l 0.124178,-0.55104 q 0.124178,0.0621 0.380294,0.14746 0.263878,0.0854 0.659695,0.0854 0.310444,0 0.519994,-0.0699 0.20955,-0.0698 0.333728,-0.18626 0.131939,-0.12418 0.186267,-0.2794 0.06209,-0.15523 0.06209,-0.32597 0,-0.26388 -0.09313,-0.46567 -0.08537,-0.20955 -0.310444,-0.34925 -0.217311,-0.1397 -0.605367,-0.20955 -0.380294,-0.0776 -0.962378,-0.0776 0.04657,-0.34149 0.06985,-0.63641 0.03105,-0.30268 0.04657,-0.58208 0.02328,-0.28716 0.03104,-0.56656 0.01552,-0.2794 0.03104,-0.58985 h 2.312811 v 0.54328 h -1.754011 q -0.0078,0.10865 -0.02328,0.28716 -0.0078,0.17074 -0.02328,0.36477 -0.01552,0.19403 -0.03104,0.37254 -0.01552,0.1785 -0.02328,0.28716 z', 'm 68.307738,278.76918 q 0,-0.6985 0.186267,-1.23401 0.194027,-0.54328 0.543277,-0.90805 0.357012,-0.36478 0.861484,-0.5588 0.504472,-0.19403 1.140883,-0.20179 l 0.05433,0.54328 q -0.411339,0.008 -0.752828,0.0931 -0.333728,0.0776 -0.597605,0.26388 -0.263878,0.1785 -0.442384,0.46566 -0.178505,0.28716 -0.271639,0.70626 0.186267,-0.0854 0.403578,-0.1397 0.225072,-0.0543 0.473428,-0.0543 0.403578,0 0.682978,0.12417 0.287161,0.12418 0.457905,0.33373 0.170745,0.20179 0.248356,0.47343 0.07761,0.27164 0.07761,0.5588 0,0.26388 -0.08537,0.54328 -0.08537,0.27164 -0.263878,0.50447 -0.178506,0.22507 -0.457906,0.37253 -0.2794,0.1397 -0.667455,0.1397 -0.799395,0 -1.195211,-0.53551 -0.395817,-0.53552 -0.395817,-1.49014 z m 1.528939,-0.49671 q -0.248356,0 -0.457906,0.0466 -0.201789,0.0466 -0.411339,0.1397 -0.0078,0.0776 -0.0078,0.15522 0,0.0698 0,0.15522 0,0.30269 0.03881,0.57433 0.04657,0.26387 0.147461,0.47342 0.108656,0.20179 0.287161,0.32597 0.178506,0.11642 0.457906,0.11642 0.232833,0 0.388055,-0.0931 0.155223,-0.10089 0.256117,-0.24835 0.100894,-0.14746 0.1397,-0.32597 0.04657,-0.18627 0.04657,-0.34925 0,-0.47343 -0.217311,-0.72178 -0.20955,-0.24836 -0.667456,-0.24836 z', 'm 72.972164,280.69394 q 0.03881,-0.55104 0.194028,-1.16417 0.162984,-0.62089 0.388056,-1.19521 0.225072,-0.58208 0.496711,-1.07103 0.271639,-0.49671 0.535517,-0.81492 h -2.328334 v -0.5588 h 3.042356 v 0.53552 q -0.232833,0.27164 -0.504472,0.72954 -0.271639,0.45791 -0.519995,1.03223 -0.240594,0.56656 -0.4191,1.21849 -0.178505,0.64418 -0.225072,1.28835 z', 'm 79.134485,279.4444 q 0,0.60537 -0.388055,0.9779 -0.380295,0.37253 -1.164167,0.37253 -0.450144,0 -0.745067,-0.11641 -0.294922,-0.12418 -0.473427,-0.31045 -0.170745,-0.19403 -0.248356,-0.42686 -0.06985,-0.23283 -0.06985,-0.4579 0,-0.41134 0.225072,-0.72955 0.225073,-0.3182 0.535517,-0.51223 -0.659694,-0.37254 -0.659694,-1.14089 0,-0.26387 0.100894,-0.50447 0.100894,-0.24059 0.287161,-0.4191 0.186267,-0.1785 0.450145,-0.28716 0.271638,-0.10865 0.605366,-0.10865 0.388056,0 0.659695,0.11641 0.2794,0.11642 0.450144,0.30269 0.170745,0.1785 0.248356,0.40357 0.07761,0.21731 0.07761,0.42686 0,0.41134 -0.20955,0.71403 -0.20955,0.29492 -0.481189,0.47342 0.799394,0.3803 0.799394,1.22626 z m -2.468033,0.0466 q 0,0.12417 0.04657,0.26387 0.04657,0.13194 0.155222,0.24836 0.108655,0.11642 0.287161,0.19403 0.178506,0.0699 0.434622,0.0699 0.240595,0 0.411339,-0.0621 0.178506,-0.0699 0.287161,-0.17851 0.116417,-0.11641 0.170745,-0.25611 0.05433,-0.1397 0.05433,-0.2794 0,-0.44239 -0.318205,-0.67522 -0.318206,-0.24059 -0.877006,-0.36477 -0.310444,0.17074 -0.481189,0.42686 -0.170744,0.25612 -0.170744,0.61313 z m 1.738489,-2.46028 q 0,-0.10089 -0.04657,-0.22507 -0.04657,-0.13194 -0.147461,-0.23283 -0.09313,-0.10866 -0.248355,-0.17851 -0.155223,-0.0776 -0.372534,-0.0776 -0.225072,0 -0.380294,0.0699 -0.147461,0.0698 -0.248356,0.17851 -0.100894,0.10089 -0.147461,0.23283 -0.0388,0.12418 -0.0388,0.24836 0,0.3182 0.225072,0.5976 0.232833,0.27164 0.760589,0.39582 0.294922,-0.17075 0.465666,-0.40358 0.178506,-0.23283 0.178506,-0.60537 z'],
    name: ['m 6.6952833,284.80119 v -0.39511 h 1.6538222 v 2.37067 q 0,0.24836 -0.056444,0.46849 -0.0508,0.22013 -0.1862667,0.38382 -0.1298222,0.15805 -0.3556,0.254 -0.2201333,0.0903 -0.5588,0.0903 -0.3386667,0 -0.5700889,-0.096 -0.2314222,-0.096 -0.3386666,-0.18627 l 0.1862666,-0.37818 q 0.1072445,0.079 0.2822222,0.16934 0.1806223,0.0903 0.4176889,0.0903 0.3612445,0 0.5362223,-0.19191 0.1806222,-0.19192 0.1806222,-0.64912 v -1.9304 z', 'm 11.397106,286.59048 q 0,0.31045 -0.09031,0.56445 -0.08467,0.24835 -0.242711,0.42898 -0.158044,0.18062 -0.378177,0.28222 -0.220134,0.096 -0.479778,0.096 -0.2540002,0 -0.4741336,-0.096 -0.2144889,-0.1016 -0.3725333,-0.28222 -0.1580445,-0.18063 -0.2483556,-0.42898 -0.084667,-0.254 -0.084667,-0.56445 0,-0.31044 0.084667,-0.56444 0.090311,-0.254 0.2483556,-0.42898 0.1580444,-0.18062 0.3725333,-0.27658 0.2201334,-0.1016 0.4741336,-0.1016 0.259644,0 0.479778,0.1016 0.220133,0.096 0.378177,0.27658 0.158045,0.17498 0.242711,0.42898 0.09031,0.254 0.09031,0.56444 z m -0.479778,0 q 0,-0.44591 -0.191911,-0.69991 -0.191911,-0.25964 -0.519289,-0.25964 -0.3217336,0 -0.5136447,0.25964 -0.1862667,0.254 -0.1862667,0.69991 0,0.44027 0.1862667,0.69991 0.1919111,0.254 0.5136447,0.254 0.327378,0 0.519289,-0.254 0.191911,-0.25964 0.191911,-0.69991 z', 'm 12.023639,285.35435 q 0.254,-0.0621 0.502355,-0.096 0.254,-0.0339 0.474134,-0.0339 0.524933,0 0.790222,0.27093 0.270933,0.27093 0.270933,0.86925 v 1.53528 h -0.462844 v -1.45062 q 0,-0.254 -0.04516,-0.41204 -0.04516,-0.15805 -0.129822,-0.24271 -0.07902,-0.0903 -0.197555,-0.12418 -0.112889,-0.0339 -0.248356,-0.0339 -0.112889,0 -0.242711,0.0169 -0.124178,0.0113 -0.242711,0.0339 v 2.21262 h -0.468489 z', 'm 15.884439,287.56697 q 0.174978,0 0.310445,-0.0113 0.141111,-0.0113 0.231422,-0.0282 v -0.77893 q -0.09031,-0.0282 -0.220133,-0.0452 -0.124178,-0.0169 -0.265289,-0.0169 -0.129822,0 -0.254,0.0226 -0.124178,0.0169 -0.220134,0.0677 -0.09596,0.0508 -0.158044,0.13547 -0.06209,0.079 -0.06209,0.2032 0,0.254 0.169333,0.3556 0.174978,0.096 0.468489,0.096 z m -0.04516,-2.34809 q 0.293511,0 0.491066,0.0734 0.2032,0.0734 0.327378,0.2032 0.124178,0.12982 0.174978,0.31609 0.0508,0.18627 0.0508,0.4064 v 1.63689 q -0.163689,0.0282 -0.434622,0.0677 -0.265289,0.0395 -0.547511,0.0395 -0.214489,0 -0.417689,-0.0395 -0.2032,-0.0339 -0.361245,-0.12418 -0.158044,-0.0959 -0.254,-0.25964 -0.09596,-0.16369 -0.09596,-0.41769 0,-0.22578 0.09596,-0.37818 0.1016,-0.15804 0.254,-0.254 0.158045,-0.096 0.3556,-0.13546 0.2032,-0.0452 0.4064,-0.0452 0.276578,0 0.541867,0.0621 v -0.12982 q 0,-0.11854 -0.02822,-0.22578 -0.02258,-0.11289 -0.09596,-0.2032 -0.06773,-0.0903 -0.191911,-0.14111 -0.118533,-0.0564 -0.310444,-0.0564 -0.242711,0 -0.423334,0.0339 -0.180622,0.0339 -0.276577,0.0677 l -0.05645,-0.38382 q 0.09596,-0.0451 0.316089,-0.079 0.225778,-0.0339 0.479778,-0.0339 z', 'm 18.638928,285.28097 h 1.106311 v 0.38947 h -1.106311 v 1.2192 q 0,0.19755 0.02822,0.32173 0.02822,0.12418 0.09031,0.2032 0.06773,0.0734 0.169333,0.1016 0.1016,0.0282 0.248356,0.0282 0.2032,0 0.327378,-0.0339 0.124178,-0.0339 0.237066,-0.0903 l 0.06773,0.39511 q -0.07902,0.0339 -0.254,0.0903 -0.169334,0.0564 -0.423334,0.0564 -0.293511,0 -0.479777,-0.0677 -0.186267,-0.0677 -0.293511,-0.2032 -0.1016,-0.13547 -0.141112,-0.33302 -0.03951,-0.2032 -0.03951,-0.46849 v -1.2192 h -0.553155 v -0.38947 h 0.553155 v -0.73378 l 0.462845,-0.079 z', 'm 20.490305,287.89999 v -3.83257 l 0.468489,-0.079 v 1.33209 q 0.112889,-0.0451 0.254,-0.0677 0.141111,-0.0282 0.276578,-0.0282 0.299155,0 0.496711,0.0903 0.2032,0.0847 0.321733,0.24271 0.118534,0.15804 0.169334,0.37818 0.0508,0.22013 0.0508,0.48542 v 1.47884 h -0.462845 v -1.37724 q 0,-0.48542 -0.135467,-0.68298 -0.135466,-0.2032 -0.485422,-0.2032 -0.146755,0 -0.287866,0.0339 -0.135467,0.0282 -0.197556,0.0564 v 2.17311 z', 'm 24.351107,287.56697 q 0.174977,0 0.310444,-0.0113 0.141111,-0.0113 0.231422,-0.0282 v -0.77893 q -0.09031,-0.0282 -0.220133,-0.0452 -0.124178,-0.0169 -0.265289,-0.0169 -0.129822,0 -0.254,0.0226 -0.124178,0.0169 -0.220133,0.0677 -0.09596,0.0508 -0.158045,0.13547 -0.06209,0.079 -0.06209,0.2032 0,0.254 0.169334,0.3556 0.174977,0.096 0.468489,0.096 z m -0.04516,-2.34809 q 0.293511,0 0.491067,0.0734 0.2032,0.0734 0.327377,0.2032 0.124178,0.12982 0.174978,0.31609 0.0508,0.18627 0.0508,0.4064 v 1.63689 q -0.163689,0.0282 -0.434622,0.0677 -0.265289,0.0395 -0.547511,0.0395 -0.214489,0 -0.417689,-0.0395 -0.2032,-0.0339 -0.361244,-0.12418 -0.158045,-0.0959 -0.254,-0.25964 -0.09596,-0.16369 -0.09596,-0.41769 0,-0.22578 0.09596,-0.37818 0.1016,-0.15804 0.254,-0.254 0.158044,-0.096 0.3556,-0.13546 0.2032,-0.0452 0.4064,-0.0452 0.276577,0 0.541866,0.0621 v -0.12982 q 0,-0.11854 -0.02822,-0.22578 -0.02258,-0.11289 -0.09596,-0.2032 -0.06773,-0.0903 -0.191911,-0.14111 -0.118533,-0.0564 -0.310444,-0.0564 -0.242711,0 -0.423333,0.0339 -0.180623,0.0339 -0.276578,0.0677 l -0.05645,-0.38382 q 0.09596,-0.0451 0.316089,-0.079 0.225778,-0.0339 0.479778,-0.0339 z', 'm 26.134751,285.35435 q 0.254,-0.0621 0.502355,-0.096 0.254,-0.0339 0.474133,-0.0339 0.524934,0 0.790223,0.27093 0.270933,0.27093 0.270933,0.86925 v 1.53528 h -0.462844 v -1.45062 q 0,-0.254 -0.04516,-0.41204 -0.04516,-0.15805 -0.129822,-0.24271 -0.07902,-0.0903 -0.197556,-0.12418 -0.112889,-0.0339 -0.248355,-0.0339 -0.112889,0 -0.242711,0.0169 -0.124178,0.0113 -0.242712,0.0339 v 2.21262 h -0.468488 z', 'm 33.974883,286.15022 q 0,0.48542 -0.124178,0.82409 -0.118533,0.33866 -0.333022,0.55315 -0.208845,0.20885 -0.502356,0.3048 -0.287866,0.096 -0.626533,0.096 -0.349956,0 -0.705556,-0.0847 v -3.38667 q 0.3556,-0.0847 0.705556,-0.0847 0.338667,0 0.626533,0.0959 0.293511,0.096 0.502356,0.31045 0.214489,0.21448 0.333022,0.55315 0.124178,0.33867 0.124178,0.81845 z m -1.8288,1.36031 q 0.141111,0.0169 0.287867,0.0169 0.254,0 0.451555,-0.0734 0.197556,-0.079 0.333022,-0.24271 0.135467,-0.16933 0.208845,-0.42898 0.07338,-0.26528 0.07338,-0.63217 0,-0.7112 -0.276578,-1.04423 -0.270934,-0.33302 -0.807156,-0.33302 -0.07338,0 -0.146755,0.006 -0.06773,0 -0.124178,0.0113 z', 'm 36.797105,286.59048 q 0,0.31045 -0.09031,0.56445 -0.08467,0.24835 -0.242712,0.42898 -0.158044,0.18062 -0.378177,0.28222 -0.220134,0.096 -0.479778,0.096 -0.254,0 -0.474133,-0.096 -0.214489,-0.1016 -0.372534,-0.28222 -0.158044,-0.18063 -0.248355,-0.42898 -0.08467,-0.254 -0.08467,-0.56445 0,-0.31044 0.08467,-0.56444 0.09031,-0.254 0.248355,-0.42898 0.158045,-0.18062 0.372534,-0.27658 0.220133,-0.1016 0.474133,-0.1016 0.259644,0 0.479778,0.1016 0.220133,0.096 0.378177,0.27658 0.158045,0.17498 0.242712,0.42898 0.09031,0.254 0.09031,0.56444 z m -0.479778,0 q 0,-0.44591 -0.191911,-0.69991 -0.191911,-0.25964 -0.519289,-0.25964 -0.321733,0 -0.513645,0.25964 -0.186266,0.254 -0.186266,0.69991 0,0.44027 0.186266,0.69991 0.191912,0.254 0.513645,0.254 0.327378,0 0.519289,-0.254 0.191911,-0.25964 0.191911,-0.69991 z', 'm 38.484795,285.21888 q 0.530578,0 0.818444,0.33302 0.287867,0.32738 0.287867,0.99907 v 0.16369 h -1.873955 q 0.02822,0.4064 0.265288,0.62089 0.242712,0.20884 0.677334,0.20884 0.248355,0 0.423333,-0.0395 0.174978,-0.0395 0.265289,-0.0847 l 0.06209,0.39511 q -0.08467,0.0451 -0.3048,0.0959 -0.220133,0.0508 -0.496711,0.0508 -0.338667,0 -0.598311,-0.1016 -0.254,-0.10724 -0.423334,-0.28786 -0.169333,-0.18063 -0.254,-0.42898 -0.08467,-0.254 -0.08467,-0.54751 0,-0.34996 0.107244,-0.6096 0.107245,-0.25965 0.282222,-0.42898 0.174978,-0.16933 0.395111,-0.254 0.220134,-0.0847 0.451556,-0.0847 z m 0.632178,1.1176 q 0,-0.33302 -0.174978,-0.52493 -0.174978,-0.19756 -0.462844,-0.19756 -0.163689,0 -0.299156,0.0621 -0.129822,0.0621 -0.225778,0.16369 -0.09595,0.1016 -0.1524,0.23142 -0.05644,0.12983 -0.07338,0.26529 z'],
    chip: {
        outer: {
            width: '13.479099',
            height: '13.432338',
            x: '27.283577',
            y: '259.17599',
            ry: '0.79374999'
        },
        inner: {
            width: '4.3201261',
            height: '4.3051386',
            x: '31.863064',
            y: '263.73959',
            ry: '0.25440127'
        },
        strokes: ['m 34.023127,259.20808 v 4.5369', 'm 34.022815,268.04802 v 4.5369', 'm 40.715172,265.89216 h -4.5369', 'm 31.781688,265.89216 h -4.5369', 'm 31.924898,263.80142 -1.647942,-1.64795', 'm 36.183189,263.73959 1.64795,-1.64795', 'm 30.215114,269.69269 1.64795,-1.64795', 'm 37.831131,269.69269 -1.647942,-1.64795', 'M 30.381947,262.19573 H 27.250646', 'M 30.320325,269.649 H 27.189023', 'M 40.855142,269.64915 H 37.723841', 'M 40.856516,262.13512 H 37.725214']
    },
    valid: ['m 40.78437,259.28667 q 0.03387,0.1778 0.08467,0.38947 0.05362,0.20885 0.110067,0.42051 0.05927,0.20885 0.118533,0.40076 0.05927,0.19191 0.110067,0.33584 0.04516,-0.14393 0.104422,-0.33866 0.06209,-0.19474 0.121355,-0.40358 0.05927,-0.21167 0.110067,-0.42051 0.05362,-0.20885 0.08749,-0.38383 h 0.242711 q -0.02258,0.11289 -0.07338,0.3048 -0.0508,0.18909 -0.121355,0.42616 -0.07056,0.23424 -0.158045,0.49953 -0.08467,0.26247 -0.1778,0.51647 h -0.287866 q -0.08749,-0.254 -0.172156,-0.51647 -0.08184,-0.26246 -0.1524,-0.49671 -0.07056,-0.23706 -0.121356,-0.42898 -0.0508,-0.19191 -0.0762,-0.3048 z', 'm 43.047792,261.03363 -0.104422,-0.4572 h -0.671689 l -0.1016,0.4572 h -0.237066 q 0.04798,-0.18627 0.107244,-0.40358 0.05927,-0.21731 0.127,-0.44591 0.07056,-0.2286 0.146756,-0.4572 0.0762,-0.23142 0.160866,-0.44027 h 0.287867 q 0.08184,0.20885 0.155222,0.44027 0.0762,0.2286 0.141111,0.4572 0.06773,0.2286 0.127,0.44591 0.05927,0.21731 0.107245,0.40358 z m -0.437444,-1.54376 q -0.06491,0.1778 -0.141111,0.41205 -0.0762,0.23424 -0.143933,0.4826 h 0.564444 q -0.06491,-0.254 -0.141111,-0.48825 -0.07338,-0.23706 -0.138289,-0.4064 z', 'm 44.616948,260.83607 v 0.19756 h -1.0414 v -1.74696 h 0.231422 v 1.5494 z', 'm 45.551104,259.48423 v 1.35184 h 0.338667 v 0.19756 h -0.908756 v -0.19756 h 0.338667 v -1.35184 h -0.338667 v -0.19756 h 0.908756 v 0.19756 z', 'm 47.43917,260.15874 q 0,0.24271 -0.06209,0.41205 -0.05927,0.16933 -0.166511,0.27657 -0.104422,0.10443 -0.251177,0.1524 -0.143934,0.048 -0.313267,0.048 -0.174978,0 -0.352778,-0.0423 v -1.69334 q 0.1778,-0.0423 0.352778,-0.0423 0.169333,0 0.313267,0.048 0.146755,0.048 0.251177,0.15522 0.107245,0.10725 0.166511,0.27658 0.06209,0.16933 0.06209,0.40922 z m -0.9144,0.68016 q 0.07056,0.008 0.143934,0.008 0.127,0 0.225777,-0.0367 0.09878,-0.0395 0.166512,-0.12135 0.06773,-0.0847 0.104422,-0.21449 0.03669,-0.13264 0.03669,-0.31609 0,-0.3556 -0.138289,-0.52211 -0.135467,-0.16651 -0.403578,-0.16651 -0.03669,0 -0.07338,0.003 -0.03387,0 -0.06209,0.006 z'],
    thru: ['m 43.231238,261.51653 v 0.19756 h -0.479777 v 1.5494 h -0.231423 v -1.5494 h -0.479777 v -0.19756 z', 'm 44.393994,261.51653 h 0.231422 v 1.74696 h -0.231422 v -0.8128 h -0.694267 v 0.8128 h -0.231422 v -1.74696 h 0.231422 v 0.7366 h 0.694267 z', 'm 45.968794,262.04993 q 0,0.16087 -0.08467,0.28505 -0.08467,0.12135 -0.2286,0.18909 0.04233,0.0677 0.09313,0.15522 0.05362,0.0847 0.107244,0.18344 0.05362,0.096 0.104422,0.20038 0.05362,0.1016 0.09878,0.20038 h -0.248356 q -0.08467,-0.2032 -0.186266,-0.38947 -0.09878,-0.18626 -0.191911,-0.30198 -0.01693,0.003 -0.0508,0.003 -0.03104,0 -0.04233,0 h -0.197555 v 0.68862 h -0.234245 v -1.72156 q 0.04233,-0.0113 0.09596,-0.0197 0.05644,-0.008 0.112889,-0.0113 0.05927,-0.006 0.115711,-0.008 0.05644,-0.003 0.1016,-0.003 0.316089,0 0.474133,0.13829 0.160867,0.13829 0.160867,0.41204 z m -0.615245,-0.34995 q -0.06491,0 -0.127,0.003 -0.05927,0 -0.08467,0.006 v 0.67452 h 0.149578 q 0.1016,0 0.180622,-0.0141 0.08184,-0.0141 0.138289,-0.0508 0.05927,-0.0395 0.09031,-0.10442 0.03104,-0.0677 0.03104,-0.17498 0,-0.1016 -0.03104,-0.16651 -0.03104,-0.0649 -0.08185,-0.1016 -0.0508,-0.0395 -0.121355,-0.0536 -0.06773,-0.0169 -0.143934,-0.0169 z', 'm 46.869083,263.30018 q -0.155222,0 -0.265289,-0.0452 -0.107244,-0.0451 -0.174978,-0.127 -0.06773,-0.0818 -0.09878,-0.20038 -0.03104,-0.11853 -0.03104,-0.26528 v -1.14583 h 0.231422 v 1.12043 q 0,0.13264 0.02258,0.22295 0.0254,0.0875 0.06773,0.14111 0.04516,0.0536 0.107245,0.0762 0.06209,0.0226 0.141111,0.0226 0.07902,0 0.141111,-0.0226 0.06209,-0.0226 0.104422,-0.0762 0.04516,-0.0536 0.06773,-0.14111 0.0254,-0.0903 0.0254,-0.22295 v -1.12043 h 0.231422 v 1.14583 q 0,0.14675 -0.03104,0.26528 -0.03104,0.11854 -0.09878,0.20038 -0.06773,0.0819 -0.1778,0.127 -0.107245,0.0452 -0.262467,0.0452 z'],
    date: ['m 49.428441,260.16666 q 0.287867,-0.11289 0.5588,-0.28222 0.270934,-0.17498 0.502356,-0.44027 h 0.327378 v 3.0988 h 0.6604 v 0.39511 h -1.8796 v -0.39511 h 0.756355 v -2.44969 q -0.06209,0.0564 -0.1524,0.11853 -0.08467,0.0564 -0.191911,0.11289 -0.1016,0.0564 -0.214489,0.10725 -0.112889,0.0508 -0.220133,0.0847 z', 'm 54.197997,260.33599 q 0,0.18062 -0.07338,0.34996 -0.06773,0.16933 -0.186267,0.33302 -0.112889,0.16369 -0.259644,0.32173 -0.146756,0.15805 -0.299156,0.31045 -0.08467,0.0847 -0.197555,0.2032 -0.112889,0.11853 -0.214489,0.24271 -0.1016,0.12418 -0.169333,0.24271 -0.06773,0.11853 -0.06773,0.2032 h 1.608667 v 0.39511 h -2.116667 q -0.0056,-0.0282 -0.0056,-0.0564 0,-0.0339 0,-0.0621 0,-0.23707 0.07902,-0.44027 0.07902,-0.2032 0.2032,-0.38382 0.124178,-0.18062 0.276578,-0.33867 0.158044,-0.16369 0.310444,-0.31609 0.124178,-0.12418 0.237067,-0.24271 0.118533,-0.11853 0.2032,-0.23707 0.09031,-0.11853 0.141111,-0.24271 0.05644,-0.12982 0.05644,-0.26529 0,-0.1524 -0.0508,-0.25964 -0.04516,-0.10724 -0.129822,-0.17498 -0.07902,-0.0734 -0.186266,-0.10724 -0.107245,-0.0339 -0.231423,-0.0339 -0.146755,0 -0.270933,0.0395 -0.118533,0.0395 -0.214489,0.096 -0.09031,0.0564 -0.158044,0.11289 -0.06773,0.0508 -0.1016,0.0847 l -0.231423,-0.32737 q 0.04516,-0.0508 0.135467,-0.12418 0.09031,-0.0734 0.214489,-0.13547 0.129822,-0.0677 0.287867,-0.11289 0.158044,-0.0451 0.338666,-0.0451 0.547511,0 0.807156,0.254 0.265289,0.24835 0.265289,0.71684 z', 'm 55.518797,263.86941 h -0.479778 l 1.5748,-4.8768 h 0.468489 z', 'm 59.994842,260.84399 q 0,1.04422 -0.508,1.5748 -0.508,0.52493 -1.529645,0.53058 l -0.01693,-0.39511 q 0.632178,0 1.016,-0.24836 0.389467,-0.254 0.513644,-0.86924 -0.135466,0.0621 -0.299155,0.1016 -0.163689,0.0339 -0.344311,0.0339 -0.299156,0 -0.502356,-0.0847 -0.2032,-0.0903 -0.327378,-0.23707 -0.124177,-0.1524 -0.180622,-0.34431 -0.05644,-0.19191 -0.05644,-0.4064 0,-0.19191 0.06209,-0.38947 0.06209,-0.2032 0.191911,-0.36689 0.129822,-0.16368 0.333022,-0.27093 0.2032,-0.10724 0.485422,-0.10724 0.575734,0 0.869245,0.39511 0.293511,0.39511 0.293511,1.08373 z m -1.1176,0.34431 q 0.180622,0 0.333022,-0.0339 0.158044,-0.0339 0.3048,-0.096 0.0056,-0.0564 0.0056,-0.10724 0,-0.0508 0,-0.10725 0,-0.22013 -0.03387,-0.41769 -0.02822,-0.19755 -0.107245,-0.34431 -0.07338,-0.14675 -0.208844,-0.23142 -0.129822,-0.0903 -0.333022,-0.0903 -0.169334,0 -0.282223,0.0734 -0.112888,0.0677 -0.186266,0.17497 -0.07338,0.1016 -0.107245,0.23143 -0.02822,0.12982 -0.02822,0.24835 0,0.34431 0.1524,0.52493 0.158045,0.17498 0.491067,0.17498 z', 'm 62.817063,260.84399 q 0,1.04422 -0.508,1.5748 -0.508,0.52493 -1.529644,0.53058 l -0.01693,-0.39511 q 0.632177,0 1.016,-0.24836 0.389466,-0.254 0.513644,-0.86924 -0.135467,0.0621 -0.299155,0.1016 -0.163689,0.0339 -0.344312,0.0339 -0.299155,0 -0.502355,-0.0847 -0.2032,-0.0903 -0.327378,-0.23707 -0.124178,-0.1524 -0.180622,-0.34431 -0.05645,-0.19191 -0.05645,-0.4064 0,-0.19191 0.06209,-0.38947 0.06209,-0.2032 0.191911,-0.36689 0.129823,-0.16368 0.333023,-0.27093 0.2032,-0.10724 0.485422,-0.10724 0.575733,0 0.869244,0.39511 0.293511,0.39511 0.293511,1.08373 z m -1.1176,0.34431 q 0.180623,0 0.333023,-0.0339 0.158044,-0.0339 0.3048,-0.096 0.0056,-0.0564 0.0056,-0.10724 0,-0.0508 0,-0.10725 0,-0.22013 -0.03387,-0.41769 -0.02822,-0.19755 -0.107244,-0.34431 -0.07338,-0.14675 -0.208844,-0.23142 -0.129823,-0.0903 -0.333023,-0.0903 -0.169333,0 -0.282222,0.0734 -0.112889,0.0677 -0.186267,0.17497 -0.07338,0.1016 -0.107244,0.23143 -0.02822,0.12982 -0.02822,0.24835 0,0.34431 0.1524,0.52493 0.158044,0.17498 0.491066,0.17498 z'],
    star: 'm 79.507287,258.6354 -5.383512,-0.17904 -2.904552,3.3845 -1.493317,-5.17535 -4.116408,-1.71652 4.460591,-3.0195 0.360473,-4.44538 4.250114,3.3092 4.339192,-1.03086 -1.833876,5.06469 z'
};

function uniqid() {
    return '_' + Math.random().toString(36).substr(2, 9);
}

var propTypes$3 = {
    bgGradientStart: PropTypes.string,
    bgGradientEnd: PropTypes.string,
    chipVariant: PropTypes.oneOf(['silver', 'gold']),
    lettersVariant: PropTypes.oneOf(['silver', 'gold']),
    withStar: PropTypes.bool
};

var defaultProps$2 = {
    bgGradientStart: '#1a845a',
    bgGradientEnd: '#58e0ab',
    chipVariant: 'silver',
    lettersVariant: 'silver',
    withStar: true
};

var getSvgStyles = function getSvgStyles(id) {
    return {
        chipStrokeStyle: {
            fill: 'none',
            stroke: '#000000',
            strokeWidth: 0.36,
            strokeLinecap: 'butt',
            strokeLinejoin: 'miter',
            strokeMiterlimit: 4,
            strokeOpacity: 1
        },
        embossStyle: {
            fill: 'url(#' + id + '-numbersGradient)',
            fillOpacity: 1,
            stroke: '#252525',
            strokeWidth: 0.075
        },
        backgroundStyle: {
            fill: 'url(#' + id + '-backgroundGradient)',
            stroke: '#000000',
            strokeWidth: '0.5'
        },
        starStyle: {
            fill: 'url(#' + id + '-starGradient)',
            fillOpacity: 1,
            fillRule: 'evenodd',
            stroke: 'none'
        }
    };
};

var CreditCard = function (_React$Component) {
    inherits$1(CreditCard, _React$Component);

    function CreditCard() {
        classCallCheck$1(this, CreditCard);
        return possibleConstructorReturn$1(this, (CreditCard.__proto__ || Object.getPrototypeOf(CreditCard)).apply(this, arguments));
    }

    createClass$1(CreditCard, [{
        key: 'render',
        value: function render() {
            var id = uniqid();

            var _props = this.props,
                chipVariant = _props.chipVariant,
                lettersVariant = _props.lettersVariant,
                other = _props.other;

            var _getSvgStyles = getSvgStyles(id),
                chipStrokeStyle = _getSvgStyles.chipStrokeStyle,
                embossStyle = _getSvgStyles.embossStyle,
                backgroundStyle = _getSvgStyles.backgroundStyle,
                starStyle = _getSvgStyles.starStyle;

            var chip = chipVariant === 'gold' ? ['#d0af5b', '#b2890b'] : ['#d6d6d6', '#9d9d9d'];
            var letters = lettersVariant === 'gold' ? ['#d0af5b', '#b2890b'] : ['#d6d6d6', '#9d9d9d'];

            var path = function path(d, index) {
                return React.createElement('path', { key: index, d: d });
            };
            var gradientProps = function gradientProps(_ref) {
                var _ref2 = slicedToArray(_ref, 5),
                    x1 = _ref2[0],
                    y1 = _ref2[1],
                    x2 = _ref2[2],
                    y2 = _ref2[3],
                    id = _ref2[4];

                return { x1: x1, y1: y1, x2: x2, y2: y2, id: id, gradientUnits: 'userSpaceOnUse' };
            };

            var star = React.createElement('path', {
                d: cardPaths.star,
                transform: 'matrix(1.2950859,0,0,1.2027212,-21.609396,-50.831723)',
                style: starStyle,
                id: 'star'
            });

            return React.createElement(
                'svg',
                _extends$1({ version: '1.1', viewBox: '0 0 85.72500 53.97500', id: id }, other),
                React.createElement(
                    'defs',
                    null,
                    React.createElement(
                        'linearGradient',
                        gradientProps([0, 300, 85, 240, id + '-backgroundGradient']),
                        React.createElement('stop', { offset: '0', style: { stopColor: this.props.bgGradientStart, stopOpacity: 1 } }),
                        React.createElement('stop', { offset: '1', style: { stopColor: this.props.bgGradientEnd, stopOpacity: 1 } })
                    ),
                    React.createElement(
                        'linearGradient',
                        gradientProps([30, 270, 40, 235, id + '-numbersGradient']),
                        React.createElement('stop', { offset: '0', style: { stopColor: letters[0], stopOpacity: 1 } }),
                        React.createElement('stop', { offset: '1', style: { stopColor: letters[1], stopOpacity: 1 } })
                    ),
                    React.createElement(
                        'linearGradient',
                        gradientProps([30, 260, 40, 270, id + '-chipGradient']),
                        React.createElement('stop', { offset: '0', style: { stopColor: chip[0], stopOpacity: 1 } }),
                        React.createElement('stop', { offset: '0.5', style: { stopColor: chip[1], stopOpacity: 1 } }),
                        React.createElement('stop', { offset: '1', style: { stopColor: chip[0], stopOpacity: 1 } })
                    ),
                    React.createElement(
                        'linearGradient',
                        gradientProps([70, 260, 85, 250, id + '-starGradient']),
                        React.createElement('stop', { offset: '0', style: { stopColor: letters[0], stopOpacity: 1 } }),
                        React.createElement('stop', { offset: '1', style: { stopColor: letters[1], stopOpacity: 0 } })
                    )
                ),
                React.createElement(
                    'g',
                    { transform: 'translate(0,-243.02499)' },
                    React.createElement('rect', {
                        ry: '4.5',
                        y: '243.17361',
                        x: '0.14814988',
                        height: '53.47500',
                        width: '85.22500',
                        style: backgroundStyle
                    }),
                    React.createElement(
                        'g',
                        { style: embossStyle, 'aria-label': '1234 5678 1234 5678' },
                        cardPaths.number.map(path)
                    ),
                    React.createElement(
                        'g',
                        { style: embossStyle, 'aria-label': 'Jonathan Doe' },
                        cardPaths.name.map(path)
                    ),
                    React.createElement(
                        'g',
                        { transform: 'translate(9.3927084,25.4)' },
                        React.createElement(
                            'g',
                            { style: embossStyle, 'aria-label': 'VALID' },
                            cardPaths.valid.map(path)
                        ),
                        React.createElement(
                            'g',
                            { style: embossStyle, 'aria-label': 'THRU' },
                            cardPaths.thru.map(path)
                        ),
                        React.createElement(
                            'g',
                            { style: embossStyle, 'aria-label': '12/99' },
                            cardPaths.date.map(path)
                        )
                    ),
                    React.createElement(
                        'g',
                        { transform: 'matrix(0.69346115,0,0,0.69346115,-5.303983,76.631011)' },
                        React.createElement('rect', _extends$1({ style: _extends$1({}, chipStrokeStyle, { fill: 'url(#' + id + '-chipGradient)', fillOpacity: 1 }) }, cardPaths.chip.outer)),
                        React.createElement('rect', _extends$1({ style: _extends$1({}, chipStrokeStyle, { fill: 'url(#' + id + '-chipGradient)', fillOpacity: 1 }) }, cardPaths.chip.inner)),
                        cardPaths.chip.strokes.map(function (path, index) {
                            return React.createElement('path', { key: index, d: path, style: chipStrokeStyle });
                        })
                    ),
                    this.props.withStar ? star : null
                )
            );
        }
    }]);
    return CreditCard;
}(React.Component);

CreditCard.defaultProps = defaultProps$2;
CreditCard.propTypes = propTypes$3;

var propTypes$4 = {
    onPixelSizeChange: PropTypes.func,
    minDiff: PropTypes.number,
    buttonsProps: PropTypes.object,
    growComponentProps: PropTypes.object,
    shrinkComponentProps: PropTypes.object,
    growComponent: PropTypes.element,
    shrinkComponent: PropTypes.element,
    cardDisplaySettings: PropTypes.shape({
        bgGradientStart: PropTypes.string,
        bgGradientEnd: PropTypes.string,
        chipVariant: PropTypes.oneOf(['silver', 'gold']),
        lettersVariant: PropTypes.oneOf(['silver', 'gold']),
        withStar: PropTypes.bool
    })
};

var defaultProps$3 = {
    onPixelSizeChange: function onPixelSizeChange() {},
    minDiff: 1
};

var CardPixelSize = function (_ResizableElement) {
    inherits$1(CardPixelSize, _ResizableElement);

    function CardPixelSize() {
        var _ref;

        var _temp, _this, _ret;

        classCallCheck$1(this, CardPixelSize);

        for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
            args[_key] = arguments[_key];
        }

        return _ret = (_temp = (_this = possibleConstructorReturn$1(this, (_ref = CardPixelSize.__proto__ || Object.getPrototypeOf(CardPixelSize)).call.apply(_ref, [this].concat(args))), _this), _this.calculateNewPixelSize = function () {
            var width = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;

            return 85725.00 / (width === null ? _this.resizable.state.width : width);
        }, _temp), possibleConstructorReturn$1(_this, _ret);
    }

    createClass$1(CardPixelSize, [{
        key: 'componentDidMount',
        value: function componentDidMount() {
            this.handlePixelSizeChange(337.5);
        }
    }, {
        key: 'render',
        value: function render() {
            var _props = this.props,
                growComponentProps = _props.growComponentProps,
                shrinkComponentProps = _props.shrinkComponentProps,
                buttonsProps = _props.buttonsProps,
                growComponent = _props.growComponent,
                shrinkComponent = _props.shrinkComponent,
                cardDisplaySettings = _props.cardDisplaySettings,
                minDiff = _props.minDiff,
                onPixelSizeChange = _props.onPixelSizeChange,
                other = objectWithoutProperties(_props, ['growComponentProps', 'shrinkComponentProps', 'buttonsProps', 'growComponent', 'shrinkComponent', 'cardDisplaySettings', 'minDiff', 'onPixelSizeChange']);


            var grow = this.getButtonComponent(growComponent, growComponentProps, this.handleGrow, 'grow');
            var shrink = this.getButtonComponent(shrinkComponent, shrinkComponentProps, this.handleShrink, 'shrink');

            return React.createElement(
                'div',
                other,
                React.createElement(
                    Resizable,
                    {
                        defaultSize: {
                            width: 337.5,
                            height: 212.5
                        },
                        lockAspectRatio: true,
                        onResize: this.handlePixelSizeChange,
                        ref: this.extractRef
                    },
                    React.createElement(CreditCard, _extends$1({ style: { width: '100%', height: '100%' } }, cardDisplaySettings))
                ),
                React.createElement(
                    'div',
                    buttonsProps,
                    grow,
                    shrink
                )
            );
        }
    }]);
    return CardPixelSize;
}(ResizableElement);

CardPixelSize.propTypes = propTypes$4;
CardPixelSize.defaultProps = defaultProps$3;

var propTypes$5 = {
    onPixelSizeChange: PropTypes.func,
    screenWidth: PropTypes.number,
    screenHeight: PropTypes.number,
    millimeters: PropTypes.bool,
    inputComponentProps: PropTypes.object,
    inputComponent: PropTypes.element
};

var defaultProps$4 = {
    onPixelSizeChange: function onPixelSizeChange() {},
    screenWidth: null,
    screenHeight: null,
    millimeters: false
};

var DiagonalPixelSize = function (_React$Component) {
    inherits$1(DiagonalPixelSize, _React$Component);

    function DiagonalPixelSize() {
        var _ref;

        var _temp, _this, _ret;

        classCallCheck$1(this, DiagonalPixelSize);

        for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
            args[_key] = arguments[_key];
        }

        return _ret = (_temp = (_this = possibleConstructorReturn$1(this, (_ref = DiagonalPixelSize.__proto__ || Object.getPrototypeOf(DiagonalPixelSize)).call.apply(_ref, [this].concat(args))), _this), _this.handleChange = function (event) {
            var _this$props = _this.props,
                screenWidth = _this$props.screenWidth,
                screenHeight = _this$props.screenHeight,
                millimeters = _this$props.millimeters;


            var width = screenWidth == null ? screen.width : screenWidth;
            var height = screenHeight == null ? screen.height : screenHeight;

            var diagonalInMm = 1000 * event.target.value / (millimeters ? 1 : 0.039370);
            var diagonalInPx = Math.sqrt(width * width + height * height);

            _this.props.onPixelSizeChange(diagonalInMm / diagonalInPx);
        }, _this.getInputComponent = function (inputComponent, inputComponentProps) {
            if (inputComponent) {
                var props = _extends$1({}, inputComponent.props, inputComponentProps, { onChange: _this.handleChange });

                return React.cloneElement(inputComponent, props);
            } else {
                return React.createElement('input', _extends$1({
                    name: 'diagonal',
                    type: 'number',
                    min: '0',
                    step: '0.01',
                    defaultValue: '1',
                    onChange: _this.handleChange
                }, inputComponentProps));
            }
        }, _temp), possibleConstructorReturn$1(_this, _ret);
    }

    createClass$1(DiagonalPixelSize, [{
        key: 'render',
        value: function render() {
            var _props = this.props,
                inputComponent = _props.inputComponent,
                inputComponentProps = _props.inputComponentProps,
                screenWidth = _props.screenWidth,
                screenHeight = _props.screenHeight,
                millimeters = _props.millimeters,
                onPixelSizeChange = _props.onPixelSizeChange,
                other = objectWithoutProperties(_props, ['inputComponent', 'inputComponentProps', 'screenWidth', 'screenHeight', 'millimeters', 'onPixelSizeChange']);


            var input = this.getInputComponent(inputComponent, inputComponentProps);

            return React.createElement(
                'div',
                other,
                input
            );
        }
    }]);
    return DiagonalPixelSize;
}(React.Component);

DiagonalPixelSize.propTypes = propTypes$5;
DiagonalPixelSize.defaultProps = defaultProps$4;

export { RulerPixelSize, CardPixelSize, DiagonalPixelSize };
//# sourceMappingURL=index.es.js.map
